@@ -9,12 +9,16 @@ ds = yt.load("IsolatedGalaxy/galaxy0030/galaxy0030")
 
 # First create a function which yields your new derived field
 def thermal_energy_dens(field, data):
-    return (3/2)*data['gas', 'number_density'] * data['gas', 'kT']
+    return (3 / 2) * data["gas", "number_density"] * data["gas", "kT"]
+
 
 # Then add it to your dataset and define the units
-ds.add_field(("gas", "thermal_energy_density"),
-             units="erg/cm**3", function=thermal_energy_dens,
-             sampling_type="cell")
+ds.add_field(
+    ("gas", "thermal_energy_density"),
+    units="erg/cm**3",
+    function=thermal_energy_dens,
+    sampling_type="cell",
+)
 
 # It will now show up in your derived_field_list
 for i in sorted(ds.derived_field_list):
@@ -22,4 +26,10 @@ for i in sorted(ds.derived_field_list):
 
 # Let's use it to make a projection
 ad = ds.all_data()
-yt.ProjectionPlot(ds, "x", "thermal_energy_density", weight_field="density", width=(200, 'kpc')).save()
+yt.ProjectionPlot(
+    ds,
+    "x",
+    ("gas", "thermal_energy_density"),
+    weight_field=("gas", "density"),
+    width=(200, "kpc"),
+).save()
