@@ -1,9 +1,10 @@
-import yt
 import matplotlib.pyplot as plt
 from mpl_toolkits.axes_grid1 import AxesGrid
 
+import yt
+
 fn = "IsolatedGalaxy/galaxy0030/galaxy0030"
-ds = yt.load(fn) # load data
+ds = yt.load(fn)  # load data
 
 fig = plt.figure()
 
@@ -12,26 +13,34 @@ fig = plt.figure()
 # four narrow colorbars, one for each plot.  Axes labels are only drawn on the
 # bottom left hand plot to avoid repeating information and make the plot less
 # cluttered.
-grid = AxesGrid(fig, (0.075,0.075,0.85,0.85),
-                nrows_ncols = (2, 2),
-                axes_pad = 1.0,
-                label_mode = "1",
-                share_all = True,
-                cbar_location="right",
-                cbar_mode="each",
-                cbar_size="3%",
-                cbar_pad="0%")
+grid = AxesGrid(
+    fig,
+    (0.075, 0.075, 0.85, 0.85),
+    nrows_ncols=(2, 2),
+    axes_pad=1.0,
+    label_mode="1",
+    share_all=True,
+    cbar_location="right",
+    cbar_mode="each",
+    cbar_size="3%",
+    cbar_pad="0%",
+)
 
-fields = ['density', 'velocity_x', 'velocity_y', 'velocity_magnitude']
+fields = [
+    ("gas", "density"),
+    ("gas", "velocity_x"),
+    ("gas", "velocity_y"),
+    ("gas", "velocity_magnitude"),
+]
 
 # Create the plot.  Since SlicePlot accepts a list of fields, we need only
 # do this once.
-p = yt.SlicePlot(ds, 'z', fields)
+p = yt.SlicePlot(ds, "z", fields)
 
 # Velocity is going to be both positive and negative, so let's make these
 # slices use a linear colorbar scale
-p.set_log('velocity_x', False)
-p.set_log('velocity_y', False)
+p.set_log(("gas", "velocity_x"), False)
+p.set_log(("gas", "velocity_y"), False)
 
 p.zoom(2)
 
@@ -46,4 +55,4 @@ for i, field in enumerate(fields):
 # Finally, redraw the plot on the AxesGrid axes.
 p._setup_plots()
 
-plt.savefig('multiplot_2x2.png')
+plt.savefig("multiplot_2x2.png")
