@@ -1,5 +1,6 @@
-import numpy as np
 import matplotlib.pyplot as plt
+import numpy as np
+
 import yt
 
 """
@@ -34,47 +35,47 @@ def doit(ds):
     ref = int(np.product(ds.ref_factors[0:max_level]))
 
     low = ds.domain_left_edge
-    dims = ds.domain_dimensions*ref
+    dims = ds.domain_dimensions * ref
 
     nx, ny, nz = dims
 
-    nindex_rho = 1./3.
+    nindex_rho = 1.0 / 3.0
 
-    Kk = np.zeros( (nx//2+1, ny//2+1, nz//2+1))
+    Kk = np.zeros((nx // 2 + 1, ny // 2 + 1, nz // 2 + 1))
 
-    for vel in [("gas", "velocity_x"), ("gas", "velocity_y"),
-                ("gas", "velocity_z")]:
+    for vel in [("gas", "velocity_x"), ("gas", "velocity_y"), ("gas", "velocity_z")]:
 
-        Kk += 0.5*fft_comp(ds, ("gas", "density"), vel,
-                           nindex_rho, max_level, low, dims)
+        Kk += 0.5 * fft_comp(
+            ds, ("gas", "density"), vel, nindex_rho, max_level, low, dims
+        )
 
     # wavenumbers
     L = (ds.domain_right_edge - ds.domain_left_edge).d
 
-    kx = np.fft.rfftfreq(nx)*nx/L[0]
-    ky = np.fft.rfftfreq(ny)*ny/L[1]
-    kz = np.fft.rfftfreq(nz)*nz/L[2]
+    kx = np.fft.rfftfreq(nx) * nx / L[0]
+    ky = np.fft.rfftfreq(ny) * ny / L[1]
+    kz = np.fft.rfftfreq(nz) * nz / L[2]
 
     # physical limits to the wavenumbers
-    kmin = np.min(1.0/L)
-    kmax = np.min(0.5*dims/L)
+    kmin = np.min(1.0 / L)
+    kmax = np.min(0.5 * dims / L)
 
     kbins = np.arange(kmin, kmax, kmin)
     N = len(kbins)
 
     # bin the Fourier KE into radial kbins
     kx3d, ky3d, kz3d = np.meshgrid(kx, ky, kz, indexing="ij")
-    k = np.sqrt(kx3d**2 + ky3d**2 + kz3d**2)
+    k = np.sqrt(kx3d ** 2 + ky3d ** 2 + kz3d ** 2)
 
     whichbin = np.digitize(k.flat, kbins)
     ncount = np.bincount(whichbin)
 
-    E_spectrum = np.zeros(len(ncount)-1)
+    E_spectrum = np.zeros(len(ncount) - 1)
 
-    for n in range(1,len(ncount)):
-        E_spectrum[n-1] = np.sum(Kk.flat[whichbin==n])
+    for n in range(1, len(ncount)):
+        E_spectrum[n - 1] = np.sum(Kk.flat[whichbin == n])
 
-    k = 0.5*(kbins[0:N-1] + kbins[1:N])
+    k = 0.5 * (kbins[0 : N - 1] + kbins[1:N])
     E_spectrum = E_spectrum[1:N]
 
     index = np.argmax(E_spectrum)
@@ -82,7 +83,7 @@ def doit(ds):
     Emax = E_spectrum[index]
 
     plt.loglog(k, E_spectrum)
-    plt.loglog(k, Emax*(k/kmax)**(-5./3.), ls=":", color="0.5")
+    plt.loglog(k, Emax * (k / kmax) ** (-5.0 / 3.0), ls=":", color="0.5")
 
     plt.xlabel(r"$k$")
     plt.ylabel(r"$E(k)dk$")
@@ -90,11 +91,9 @@ def doit(ds):
     plt.savefig("spectrum.png")
 
 
-def fft_comp(ds, irho, iu, nindex_rho, level, low, delta ):
+def fft_comp(ds, irho, iu, nindex_rho, level, low, delta):
 
-    cube = ds.covering_grid(level, left_edge=low,
-                            dims=delta,
-                            fields=[irho, iu])
+    cube = ds.covering_grid(level, left_edge=low, dims=delta, fields=[irho, iu])
 
     rho = cube[irho].d
     u = cube[iu].d
@@ -106,11 +105,12 @@ def fft_comp(ds, irho, iu, nindex_rho, level, low, delta ):
     # the first half of the axes -- that's what we keep.  Our
     # normalization has an '8' to account for this clipping to one
     # octant.
-    ru = np.fft.fftn(rho**nindex_rho * u)[0:nx//2+1,0:ny//2+1,0:nz//2+1]
-    ru = 8.0*ru/(nx*ny*nz)
-
-    return np.abs(ru)**2
+    ru = np.fft.fftn(rho ** nindex_rho * u)[
+        0 : nx // 2 + 1, 0 : ny // 2 + 1, 0 : nz // 2 + 1
+    ]
+    ru = 8.0 * ru / (nx * ny * nz)
 
+    return np.abs(ru) ** 2
 
 
 ds = yt.load("maestro_xrb_lores_23437")
