@@ -1,60 +1,45 @@
-"""
-Quantities that can be derived from Enzo data that may also required additional
-arguments.  (Standard arguments -- such as the center of a distribution of
-points -- are excluded here, and left to the EnzoDerivedFields.)
-
-
-
-"""
-
-#-----------------------------------------------------------------------------
-# Copyright (c) 2013, yt Development Team.
-#
-# Distributed under the terms of the Modified BSD License.
-#
-# The full license is in the file COPYING.txt, distributed with this software.
-#-----------------------------------------------------------------------------
-
 import numpy as np
 
-from yt.funcs import \
-    camelcase_to_underscore, \
-    ensure_list
+from yt._maintenance.deprecation import issue_deprecation_warning
+from yt.funcs import camelcase_to_underscore, iter_fields
 from yt.units.yt_array import array_like_field
-from yt.utilities.parallel_tools.parallel_analysis_interface import \
-    ParallelAnalysisInterface, parallel_objects
-from yt.utilities.physical_constants import \
-    gravitational_constant_cgs
+from yt.utilities.exceptions import YTParticleTypeNotFound
+from yt.utilities.object_registries import derived_quantity_registry
+from yt.utilities.parallel_tools.parallel_analysis_interface import (
+    ParallelAnalysisInterface,
+    parallel_objects,
+)
+from yt.utilities.physical_constants import gravitational_constant_cgs
 from yt.utilities.physical_ratios import HUGE
-from yt.extern.six import add_metaclass
-from yt.utilities.exceptions import \
-    YTParticleTypeNotFound
 
-derived_quantity_registry = {}
 
 def get_position_fields(field, data):
     axis_names = [data.ds.coordinates.axis_name[num] for num in [0, 1, 2]]
-    if field[0] in data.ds.particle_types:
-        position_fields = [(field[0], 'particle_position_%s' % d)
-                           for d in axis_names]
+    field = data._determine_fields(field)[0]
+    finfo = data.ds.field_info[field]
+    if finfo.sampling_type == "particle":
+        if finfo.alias_field:
+            ftype = finfo.alias_name[0]
+        else:
+            ftype = finfo.name[0]
+        position_fields = [(ftype, f"particle_position_{d}") for d in axis_names]
     else:
-        position_fields = axis_names
+        position_fields = [("index", ax_name) for ax_name in axis_names]
 
     return position_fields
 
-class RegisteredDerivedQuantity(type):
-    def __init__(cls, name, b, d):
-        type.__init__(cls, name, b, d)
-        if name != "DerivedQuantity":
-            derived_quantity_registry[name] = cls
 
-@add_metaclass(RegisteredDerivedQuantity)
 class DerivedQuantity(ParallelAnalysisInterface):
     num_vals = -1
 
     def __init__(self, data_source):
         self.data_source = data_source
 
+    def __init_subclass__(cls, *args, **kwargs):
+        super().__init_subclass__(*args, **kwargs)
+        if cls.__name__ != "DerivedQuantity":
+            derived_quantity_registry[cls.__name__] = cls
+
     def count_values(self, *args, **kwargs):
         return
 
@@ -63,14 +48,16 @@ class DerivedQuantity(ParallelAnalysisInterface):
         # create the index if it doesn't exist yet
         self.data_source.ds.index
         self.count_values(*args, **kwargs)
-        chunks = self.data_source.chunks([], chunking_style="io")
+        chunks = self.data_source.chunks(
+            [], chunking_style=self.data_source._derived_quantity_chunking
+        )
         storage = {}
-        for sto, ds in parallel_objects(chunks, -1, storage = storage):
+        for sto, ds in parallel_objects(chunks, -1, storage=storage):
             sto.result = self.process_chunk(ds, *args, **kwargs)
         # Now storage will have everything, and will be done via pickling, so
         # the units will be preserved.  (Credit to Nathan for this
         # idea/implementation.)
-        values = [ [] for i in range(self.num_vals) ]
+        values = [[] for i in range(self.num_vals)]
         for key in sorted(storage):
             for i in range(self.num_vals):
                 values[i].append(storage[key][i])
@@ -85,7 +72,8 @@ class DerivedQuantity(ParallelAnalysisInterface):
     def reduce_intermediate(self, values):
         raise NotImplementedError
 
-class DerivedQuantityCollection(object):
+
+class DerivedQuantityCollection:
     def __new__(cls, data_source, *args, **kwargs):
         inst = object.__new__(cls)
         inst.data_source = data_source
@@ -103,6 +91,7 @@ class DerivedQuantityCollection(object):
     def keys(self):
         return derived_quantity_registry.keys()
 
+
 class WeightedAverageQuantity(DerivedQuantity):
     r"""
     Calculates the weight average of a field or fields.
@@ -127,30 +116,34 @@ class WeightedAverageQuantity(DerivedQuantity):
 
     >>> ds = load("IsolatedGalaxy/galaxy0030/galaxy0030")
     >>> ad = ds.all_data()
-    >>> print ad.quantities.weighted_average_quantity([("gas", "density"),
-    ...                                                ("gas", "temperature")],
-    ...                                               ("gas", "cell_mass"))
+    >>> print(
+    ...     ad.quantities.weighted_average_quantity(
+    ...         [("gas", "density"), ("gas", "temperature")], ("gas", "mass")
+    ...     )
+    ... )
 
     """
+
     def count_values(self, fields, weight):
         # This is a list now
         self.num_vals = len(fields) + 1
 
     def __call__(self, fields, weight):
-        fields = ensure_list(fields)
-        rv = super(WeightedAverageQuantity, self).__call__(fields, weight)
-        if len(rv) == 1: rv = rv[0]
+        fields = list(iter_fields(fields))
+        rv = super().__call__(fields, weight)
+        if len(rv) == 1:
+            rv = rv[0]
         return rv
 
     def process_chunk(self, data, fields, weight):
-        vals = [(data[field] * data[weight]).sum(dtype=np.float64)
-                for field in fields]
+        vals = [(data[field] * data[weight]).sum(dtype=np.float64) for field in fields]
         wv = data[weight].sum(dtype=np.float64)
         return vals + [wv]
 
     def reduce_intermediate(self, values):
         w = values.pop(-1).sum(dtype=np.float64)
-        return [v.sum(dtype=np.float64)/w for v in values]
+        return [v.sum(dtype=np.float64) / w for v in values]
+
 
 class TotalQuantity(DerivedQuantity):
     r"""
@@ -166,27 +159,29 @@ class TotalQuantity(DerivedQuantity):
 
     >>> ds = load("IsolatedGalaxy/galaxy0030/galaxy0030")
     >>> ad = ds.all_data()
-    >>> print ad.quantities.total_quantity([("gas", "cell_mass")])
+    >>> print(ad.quantities.total_quantity([("gas", "mass")]))
 
     """
+
     def count_values(self, fields):
         # This is a list now
         self.num_vals = len(fields)
 
     def __call__(self, fields):
-        fields = ensure_list(fields)
-        rv = super(TotalQuantity, self).__call__(fields)
-        if len(rv) == 1: rv = rv[0]
+        fields = list(iter_fields(fields))
+        rv = super().__call__(fields)
+        if len(rv) == 1:
+            rv = rv[0]
         return rv
 
     def process_chunk(self, data, fields):
-        vals = [data[field].sum(dtype=np.float64)
-                for field in fields]
+        vals = [data[field].sum(dtype=np.float64) for field in fields]
         return vals
 
     def reduce_intermediate(self, values):
         return [v.sum(dtype=np.float64) for v in values]
 
+
 class TotalMass(TotalQuantity):
     r"""
     Calculates the total mass of the object. Returns a YTArray where the
@@ -198,22 +193,24 @@ class TotalMass(TotalQuantity):
 
     >>> ds = load("IsolatedGalaxy/galaxy0030/galaxy0030")
     >>> ad = ds.all_data()
-    >>> print ad.quantities.total_mass()
+    >>> print(ad.quantities.total_mass())
 
     """
+
     def __call__(self):
         self.data_source.ds.index
         fi = self.data_source.ds.field_info
-        if ("gas", "cell_mass") in fi:
-            gas = super(TotalMass, self).__call__([('gas', 'cell_mass')])
+        if ("gas", "mass") in fi:
+            gas = super().__call__([("gas", "mass")])
         else:
-            gas = self.data_source.ds.arr([0], 'g')
-        if ("all", "particle_mass") in fi:
-            part = super(TotalMass, self).__call__([('all', 'particle_mass')])
+            gas = self.data_source.ds.quan(0.0, "g")
+        if ("nbody", "particle_mass") in fi:
+            part = super().__call__([("nbody", "particle_mass")])
         else:
-            part = self.data_source.ds.arr([0], 'g')
+            part = self.data_source.ds.quan(0.0, "g")
         return self.data_source.ds.arr([gas, part])
 
+
 class CenterOfMass(DerivedQuantity):
     r"""
     Calculates the center of mass, using gas and/or particles.
@@ -241,37 +238,42 @@ class CenterOfMass(DerivedQuantity):
 
     >>> ds = load("IsolatedGalaxy/galaxy0030/galaxy0030")
     >>> ad = ds.all_data()
-    >>> print ad.quantities.center_of_mass()
+    >>> print(ad.quantities.center_of_mass())
 
     """
-    def count_values(self, use_gas = True, use_particles = False, particle_type="all"):
-        if use_particles and particle_type not in self.data_source.ds.particle_types:
-            raise YTParticleTypeNotFound(particle_type,self.data_source.ds)
-        use_gas &= \
-          (("gas", "cell_mass") in self.data_source.ds.field_info)
-        use_particles &= \
-          ((particle_type, "particle_mass") in self.data_source.ds.field_info)
+
+    def count_values(self, use_gas=True, use_particles=False, particle_type="nbody"):
+        finfo = self.data_source.ds.field_info
+        includes_gas = ("gas", "mass") in finfo
+        includes_particles = (particle_type, "particle_mass") in finfo
+
+        self.use_gas = use_gas & includes_gas
+        self.use_particles = use_particles & includes_particles
+
         self.num_vals = 0
-        if use_gas:
+        if self.use_gas:
             self.num_vals += 4
-        if use_particles:
+        if self.use_particles:
             self.num_vals += 4
 
-    def process_chunk(self, data, use_gas = True, use_particles = False, particle_type="all"):
-        use_gas &= \
-          (("gas", "cell_mass") in self.data_source.ds.field_info)
-        use_particles &= \
-          ((particle_type, "particle_mass") in self.data_source.ds.field_info)
+    def process_chunk(
+        self, data, use_gas=True, use_particles=False, particle_type="nbody"
+    ):
         vals = []
-        if use_gas:
-            vals += [(data["gas", ax] *
-                      data["gas", "cell_mass"]).sum(dtype=np.float64)
-                     for ax in 'xyz']
-            vals.append(data["gas", "cell_mass"].sum(dtype=np.float64))
-        if use_particles:
-            vals += [(data[particle_type, "particle_position_%s" % ax] *
-                      data[particle_type, "particle_mass"]).sum(dtype=np.float64)
-                     for ax in 'xyz']
+        if self.use_gas:
+            vals += [
+                (data["gas", ax] * data["gas", "mass"]).sum(dtype=np.float64)
+                for ax in "xyz"
+            ]
+            vals.append(data["gas", "mass"].sum(dtype=np.float64))
+        if self.use_particles:
+            vals += [
+                (
+                    data[particle_type, f"particle_position_{ax}"]
+                    * data[particle_type, "particle_mass"]
+                ).sum(dtype=np.float64)
+                for ax in "xyz"
+            ]
             vals.append(data[particle_type, "particle_mass"].sum(dtype=np.float64))
         return vals
 
@@ -289,7 +291,8 @@ class CenterOfMass(DerivedQuantity):
             y += values.pop(0).sum(dtype=np.float64)
             z += values.pop(0).sum(dtype=np.float64)
             w += values.pop(0).sum(dtype=np.float64)
-        return self.data_source.ds.arr([v/w for v in [x, y, z]])
+        return self.data_source.ds.arr([v / w for v in [x, y, z]])
+
 
 class BulkVelocity(DerivedQuantity):
     r"""
@@ -318,30 +321,40 @@ class BulkVelocity(DerivedQuantity):
 
     >>> ds = load("IsolatedGalaxy/galaxy0030/galaxy0030")
     >>> ad = ds.all_data()
-    >>> print ad.quantities.bulk_velocity()
+    >>> print(ad.quantities.bulk_velocity())
 
     """
-    def count_values(self, use_gas = True, use_particles = False, particle_type= "all"):
+
+    def count_values(self, use_gas=True, use_particles=False, particle_type="nbody"):
         if use_particles and particle_type not in self.data_source.ds.particle_types:
-            raise YTParticleTypeNotFound(particle_type,self.data_source.ds)
+            raise YTParticleTypeNotFound(particle_type, self.data_source.ds)
         # This is a list now
         self.num_vals = 0
         if use_gas:
             self.num_vals += 4
-        if use_particles:
+        if use_particles and "nbody" in self.data_source.ds.particle_types:
             self.num_vals += 4
 
-    def process_chunk(self, data, use_gas = True, use_particles = False, particle_type= "all"):
+    def process_chunk(
+        self, data, use_gas=True, use_particles=False, particle_type="nbody"
+    ):
         vals = []
         if use_gas:
-            vals += [(data["gas", "velocity_%s" % ax] *
-                      data["gas", "cell_mass"]).sum(dtype=np.float64)
-                     for ax in 'xyz']
-            vals.append(data["gas", "cell_mass"].sum(dtype=np.float64))
-        if use_particles:
-            vals += [(data[particle_type, "particle_velocity_%s" % ax] *
-                      data[particle_type, "particle_mass"]).sum(dtype=np.float64)
-                     for ax in 'xyz']
+            vals += [
+                (data["gas", f"velocity_{ax}"] * data["gas", "mass"]).sum(
+                    dtype=np.float64
+                )
+                for ax in "xyz"
+            ]
+            vals.append(data["gas", "mass"].sum(dtype=np.float64))
+        if use_particles and "nbody" in data.ds.particle_types:
+            vals += [
+                (
+                    data[particle_type, f"particle_velocity_{ax}"]
+                    * data[particle_type, "particle_mass"]
+                ).sum(dtype=np.float64)
+                for ax in "xyz"
+            ]
             vals.append(data[particle_type, "particle_mass"].sum(dtype=np.float64))
         return vals
 
@@ -359,19 +372,20 @@ class BulkVelocity(DerivedQuantity):
             y += values.pop(0).sum(dtype=np.float64)
             z += values.pop(0).sum(dtype=np.float64)
             w += values.pop(0).sum(dtype=np.float64)
-        return self.data_source.ds.arr([v/w for v in [x, y, z]])
+        return self.data_source.ds.arr([v / w for v in [x, y, z]])
 
-class WeightedVariance(DerivedQuantity):
+
+class WeightedStandardDeviation(DerivedQuantity):
     r"""
-    Calculates the weighted variance and weighted mean for a field
+    Calculates the weighted standard deviation and weighted mean for a field
     or list of fields. Returns a YTArray for each field requested; if one,
     it returns a single YTArray, if many, it returns a list of YTArrays
     in order of the listed fields.  The first element of each YTArray is
-    the weighted variance, and the second element is the weighted mean.
+    the weighted standard deviation, and the second element is the weighted mean.
 
     Where f is the field, w is the weight, and <f_w> is the weighted mean,
-    the weighted variance is
-    Sum_i( (f_i - <f_w>)^2 \* w_i ) / Sum_i(w_i).
+    the weighted standard deviation is
+    sqrt( Sum_i( (f_i - <f_w>)^2 \* w_i ) / Sum_i(w_i) ).
 
     Parameters
     ----------
@@ -386,31 +400,40 @@ class WeightedVariance(DerivedQuantity):
 
     >>> ds = load("IsolatedGalaxy/galaxy0030/galaxy0030")
     >>> ad = ds.all_data()
-    >>> print ad.quantities.weighted_variance([("gas", "density"),
-    ...                                        ("gas", "temperature")],
-    ...                                       ("gas", "cell_mass"))
+    >>> print(
+    ...     ad.quantities.weighted_standard_deviation(
+    ...         [("gas", "density"), ("gas", "temperature")], ("gas", "mass")
+    ...     )
+    ... )
 
     """
+
     def count_values(self, fields, weight):
         # This is a list now
         self.num_vals = 2 * len(fields) + 1
 
     def __call__(self, fields, weight):
-        fields = ensure_list(fields)
-        rv = super(WeightedVariance, self).__call__(fields, weight)
-        if len(rv) == 1: rv = rv[0]
+        fields = list(iter_fields(fields))
+        units = [self.data_source.ds._get_field_info(field).units for field in fields]
+        rv = super().__call__(fields, weight)
+        rv = [self.data_source.ds.arr(v, u) for v, u in zip(rv, units)]
+        if len(rv) == 1:
+            rv = rv[0]
         return rv
 
     def process_chunk(self, data, fields, weight):
-        my_weight = data[weight].sum(dtype=np.float64)
+        my_weight = data[weight].d.sum(dtype=np.float64)
         if my_weight == 0:
-            return [0.0 for field in fields] + \
-              [0.0 for field in fields] + [0.0]
-        my_means = [(data[field] *  data[weight]).sum(dtype=np.float64) / my_weight
-                    for field in fields]
-        my_var2s = [(data[weight] * (data[field] -
-                                     my_mean)**2).sum(dtype=np.float64) / my_weight
-                   for field, my_mean in zip(fields, my_means)]
+            return [0.0 for field in fields] + [0.0 for field in fields] + [0.0]
+        my_means = [
+            (data[field].d * data[weight].d).sum(dtype=np.float64) / my_weight
+            for field in fields
+        ]
+        my_var2s = [
+            (data[weight].d * (data[field].d - my_mean) ** 2).sum(dtype=np.float64)
+            / my_weight
+            for field, my_mean in zip(fields, my_means)
+        ]
         return my_means + my_var2s + [my_weight]
 
     def reduce_intermediate(self, values):
@@ -421,12 +444,33 @@ class WeightedVariance(DerivedQuantity):
             my_mean = values[i]
             my_var2 = values[i + int(len(values) / 2)]
             all_mean = (my_weight * my_mean).sum(dtype=np.float64) / all_weight
-            rvals.append(self.data_source.ds.arr([(np.sqrt((my_weight *
-                                                 (my_var2 + (my_mean -
-                                                  all_mean)**2)).sum(dtype=np.float64)
-                                                  / all_weight)), all_mean]))
+            ret = [
+                (
+                    np.sqrt(
+                        (my_weight * (my_var2 + (my_mean - all_mean) ** 2)).sum(
+                            dtype=np.float64
+                        )
+                        / all_weight
+                    )
+                ),
+                all_mean,
+            ]
+            rvals.append(np.array(ret))
         return rvals
 
+
+class WeightedVariance(WeightedStandardDeviation):
+    def __call__(self, fields, weight):
+        issue_deprecation_warning(
+            "'weighted_variance' incorrectly returns the "
+            "standard deviation and has been deprecated. "
+            "Use 'weighted_standard_deviation' instead.",
+            since="4.0.0",
+            removal="4.1.0",
+        )
+        return super().__call__(fields, weight)
+
+
 class AngularMomentumVector(DerivedQuantity):
     r"""
     Calculates the angular momentum vector, using gas (grid-based) and/or particles.
@@ -453,61 +497,84 @@ class AngularMomentumVector(DerivedQuantity):
     Examples
     --------
 
-    # Find angular momentum vector of galaxy in grid-based isolated galaxy dataset
-    >>> ds = load("IsolatedGalaxy/galaxy0030/galaxy0030")
-    >>> ad = ds.all_data()
-    >>> print ad.quantities.angular_momentum_vector()
-
-    # Find angular momentum vector of gas disk in particle-based dataset
-    >>> ds = load("FIRE_M12i_ref11/snapshot_600.hdf5")
-    >>> _, c = ds.find_max(('gas', 'density'))
-    >>> sp = ds.sphere(c, (10, 'kpc'))
-    >>> print sp.quantities.angular_momentum_vector(use_gas=False, use_particles=True, particle_type='PartType0')
+    Find angular momentum vector of galaxy in grid-based isolated galaxy dataset
+    >>> ds = yt.load("IsolatedGalaxy/galaxy0030/galaxy0030")
+    ... ad = ds.all_data()
+    ... print(ad.quantities.angular_momentum_vector())
+    [-7.50868209e+26  1.06032596e+27  2.19274002e+29] cm**2/s
+    >>> # Find angular momentum vector of gas disk in particle-based dataset
+    >>> ds = yt.load("FIRE_M12i_ref11/snapshot_600.hdf5")
+    ... _, c = ds.find_max(("gas", "density"))
+    ... sp = ds.sphere(c, (10, "kpc"))
+    ... search_args = dict(use_gas=False, use_particles=True, particle_type="PartType0")
+    ... print(sp.quantities.angular_momentum_vector(**search_args))
+    [4.88104442e+28 7.38463362e+28 6.20030135e+28] cm**2/s
 
     """
-    def count_values(self, use_gas=True, use_particles=True, particle_type = "all"):
+
+    def count_values(self, use_gas=True, use_particles=True, particle_type="all"):
         if use_particles and particle_type not in self.data_source.ds.particle_types:
-            raise YTParticleTypeNotFound(particle_type,self.data_source.ds)
+            raise YTParticleTypeNotFound(particle_type, self.data_source.ds)
         num_vals = 0
         # create the index if it doesn't exist yet
         self.data_source.ds.index
         self.particle_type = particle_type
-        self.use_gas = use_gas & \
-            (("gas", "cell_mass") in self.data_source.ds.field_info)
-        self.use_particles = use_particles & \
-            ((self.particle_type, "particle_mass") in self.data_source.ds.field_info)
+        self.use_gas = use_gas & (("gas", "mass") in self.data_source.ds.field_info)
+        self.use_particles = use_particles & (
+            (self.particle_type, "particle_mass") in self.data_source.ds.field_info
+        )
         if self.use_gas:
             num_vals += 4
         if self.use_particles:
             num_vals += 4
         self.num_vals = num_vals
 
-    def process_chunk(self, data, use_gas = True, use_particles = False, particle_type= "all"):
+    def process_chunk(
+        self, data, use_gas=True, use_particles=False, particle_type="all"
+    ):
         rvals = []
         if self.use_gas:
-            rvals.extend([(data["gas", "specific_angular_momentum_%s" % axis] *
-                           data["gas", "cell_mass"]).sum(dtype=np.float64) \
-                          for axis in "xyz"])
-            rvals.append(data["gas", "cell_mass"].sum(dtype=np.float64))
+            rvals.extend(
+                [
+                    (
+                        data["gas", f"specific_angular_momentum_{axis}"]
+                        * data["gas", "mass"]
+                    ).sum(dtype=np.float64)
+                    for axis in "xyz"
+                ]
+            )
+            rvals.append(data["gas", "mass"].sum(dtype=np.float64))
         if self.use_particles:
-            rvals.extend([(data[self.particle_type, "particle_specific_angular_momentum_%s" % axis] *
-                           data[self.particle_type, "particle_mass"]).sum(dtype=np.float64) \
-                          for axis in "xyz"])
-            rvals.append(data[self.particle_type, "particle_mass"].sum(dtype=np.float64))
+            rvals.extend(
+                [
+                    (
+                        data[
+                            self.particle_type,
+                            f"particle_specific_angular_momentum_{axis}",
+                        ]
+                        * data[self.particle_type, "particle_mass"]
+                    ).sum(dtype=np.float64)
+                    for axis in "xyz"
+                ]
+            )
+            rvals.append(
+                data[self.particle_type, "particle_mass"].sum(dtype=np.float64)
+            )
         return rvals
 
     def reduce_intermediate(self, values):
         jx = values.pop(0).sum(dtype=np.float64)
         jy = values.pop(0).sum(dtype=np.float64)
         jz = values.pop(0).sum(dtype=np.float64)
-        m  = values.pop(0).sum(dtype=np.float64)
+        m = values.pop(0).sum(dtype=np.float64)
         if values:
             jx += values.pop(0).sum(dtype=np.float64)
             jy += values.pop(0).sum(dtype=np.float64)
             jz += values.pop(0).sum(dtype=np.float64)
-            m  += values.pop(0).sum(dtype=np.float64)
+            m += values.pop(0).sum(dtype=np.float64)
         return self.data_source.ds.arr([jx / m, jy / m, jz / m])
 
+
 class Extrema(DerivedQuantity):
     r"""
     Calculates the min and max value of a field or list of fields.
@@ -530,17 +597,18 @@ class Extrema(DerivedQuantity):
 
     >>> ds = load("IsolatedGalaxy/galaxy0030/galaxy0030")
     >>> ad = ds.all_data()
-    >>> print ad.quantities.extrema([("gas", "density"),
-    ...                              ("gas", "temperature")])
+    >>> print(ad.quantities.extrema([("gas", "density"), ("gas", "temperature")]))
 
     """
+
     def count_values(self, fields, non_zero):
         self.num_vals = len(fields) * 2
 
-    def __call__(self, fields, non_zero = False):
-        fields = ensure_list(fields)
-        rv = super(Extrema, self).__call__(fields, non_zero)
-        if len(rv) == 1: rv = rv[0]
+    def __call__(self, fields, non_zero=False):
+        fields = list(iter_fields(fields))
+        rv = super().__call__(fields, non_zero)
+        if len(rv) == 1:
+            rv = rv[0]
         return rv
 
     def process_chunk(self, data, fields, non_zero):
@@ -548,18 +616,24 @@ class Extrema(DerivedQuantity):
         for field in fields:
             field = data._determine_fields(field)[0]
             fd = data[field]
-            if non_zero: fd = fd[fd > 0.0]
+            if non_zero:
+                fd = fd[fd > 0.0]
             if fd.size > 0:
                 vals += [fd.min(), fd.max()]
             else:
-                vals += [array_like_field(data, HUGE, field),
-                         array_like_field(data, -HUGE, field)]
+                vals += [
+                    array_like_field(data, HUGE, field),
+                    array_like_field(data, -HUGE, field),
+                ]
         return vals
 
     def reduce_intermediate(self, values):
         # The values get turned into arrays here.
-        return [self.data_source.ds.arr([mis.min(), mas.max()])
-                for mis, mas in zip(values[::2], values[1::2])]
+        return [
+            self.data_source.ds.arr([mis.min(), mas.max()])
+            for mis, mas in zip(values[::2], values[1::2])
+        ]
+
 
 class SampleAtMaxFieldValues(DerivedQuantity):
     _sign = -1
@@ -579,22 +653,24 @@ class SampleAtMaxFieldValues(DerivedQuantity):
 
     >>> ds = load("IsolatedGalaxy/galaxy0030/galaxy0030")
     >>> ad = ds.all_data()
-    >>> print ad.quantities.sample_at_max_field_values(("gas", "density"),
-    ...         ["temperature", "velocity_magnitude"])
+    >>> print(ad.quantities.sample_at_max_field_values(("gas", "density"),
+    ...         [("gas", "temperature"), ("gas", "velocity_magnitude")]))
 
     """
+
     def count_values(self, field, sample_fields):
         # field itself, then index, then the number of sample fields
         self.num_vals = 1 + len(sample_fields)
 
     def __call__(self, field, sample_fields):
-        rv = super(SampleAtMaxFieldValues, self).__call__(field, sample_fields)
-        if len(rv) == 1: rv = rv[0]
+        rv = super().__call__(field, sample_fields)
+        if len(rv) == 1:
+            rv = rv[0]
         return rv
 
     def process_chunk(self, data, field, sample_fields):
         field = data._determine_fields(field)[0]
-        ma = array_like_field(data, self._sign*HUGE, field)
+        ma = array_like_field(data, self._sign * HUGE, field)
         vals = [array_like_field(data, -1, sf) for sf in sample_fields]
         maxi = -1
         if data[field].size > 0:
@@ -604,12 +680,13 @@ class SampleAtMaxFieldValues(DerivedQuantity):
         return (ma,) + tuple(vals)
 
     def reduce_intermediate(self, values):
-        i = self._func(values[0]) # ma is values[0]
+        i = self._func(values[0])  # ma is values[0]
         return [val[i] for val in values]
 
     def _func(self, arr):
         return np.argmax(arr)
 
+
 class MaxLocation(SampleAtMaxFieldValues):
     r"""
     Calculates the maximum value plus the x, y, and z position of the maximum.
@@ -625,17 +702,20 @@ class MaxLocation(SampleAtMaxFieldValues):
 
     >>> ds = load("IsolatedGalaxy/galaxy0030/galaxy0030")
     >>> ad = ds.all_data()
-    >>> print ad.quantities.max_location(("gas", "density"))
+    >>> print(ad.quantities.max_location(("gas", "density")))
 
     """
+
     def __call__(self, field):
         # Make sure we have an index
         self.data_source.index
         sample_fields = get_position_fields(field, self.data_source)
-        rv = super(MaxLocation, self).__call__(field, sample_fields)
-        if len(rv) == 1: rv = rv[0]
+        rv = super().__call__(field, sample_fields)
+        if len(rv) == 1:
+            rv = rv[0]
         return rv
 
+
 class SampleAtMinFieldValues(SampleAtMaxFieldValues):
     _sign = 1
     r"""
@@ -654,13 +734,15 @@ class SampleAtMinFieldValues(SampleAtMaxFieldValues):
 
     >>> ds = load("IsolatedGalaxy/galaxy0030/galaxy0030")
     >>> ad = ds.all_data()
-    >>> print ad.quantities.sample_at_min_field_values(("gas", "density"),
-    ...         ["temperature", "velocity_magnitude"])
+    >>> print(ad.quantities.sample_at_min_field_values(("gas", "density"),
+    ...         [("gas", "temperature"), ("gas", "velocity_magnitude")]))
 
     """
+
     def _func(self, arr):
         return np.argmin(arr)
 
+
 class MinLocation(SampleAtMinFieldValues):
     r"""
     Calculates the minimum value plus the x, y, and z position of the minimum.
@@ -676,17 +758,20 @@ class MinLocation(SampleAtMinFieldValues):
 
     >>> ds = load("IsolatedGalaxy/galaxy0030/galaxy0030")
     >>> ad = ds.all_data()
-    >>> print ad.quantities.min_location(("gas", "density"))
+    >>> print(ad.quantities.min_location(("gas", "density")))
 
     """
+
     def __call__(self, field):
         # Make sure we have an index
         self.data_source.index
         sample_fields = get_position_fields(field, self.data_source)
-        rv = super(MinLocation, self).__call__(field, sample_fields)
-        if len(rv) == 1: rv = rv[0]
+        rv = super().__call__(field, sample_fields)
+        if len(rv) == 1:
+            rv = rv[0]
         return rv
 
+
 class SpinParameter(DerivedQuantity):
     r"""
     Calculates the dimensionless spin parameter.
@@ -721,31 +806,40 @@ class SpinParameter(DerivedQuantity):
 
     >>> ds = load("IsolatedGalaxy/galaxy0030/galaxy0030")
     >>> ad = ds.all_data()
-    >>> print ad.quantities.spin_parameter()
+    >>> print(ad.quantities.spin_parameter())
 
     """
+
     def count_values(self, **kwargs):
         self.num_vals = 3
 
-    def process_chunk(self, data, use_gas=True, use_particles=True, particle_type= "all"):
+    def process_chunk(
+        self, data, use_gas=True, use_particles=True, particle_type="nbody"
+    ):
         if use_particles and particle_type not in self.data_source.ds.particle_types:
-            raise YTParticleTypeNotFound(particle_type,self.data_source.ds)
-        use_gas &= \
-          (("gas", "cell_mass") in self.data_source.ds.field_info)
-        use_particles &= \
-          ((particle_type, "particle_mass") in self.data_source.ds.field_info)
-        e = data.ds.quan(0., "erg")
-        j = data.ds.quan(0., "g*cm**2/s")
-        m = data.ds.quan(0., "g")
+            raise YTParticleTypeNotFound(particle_type, self.data_source.ds)
+        use_gas &= ("gas", "mass") in self.data_source.ds.field_info
+        use_particles &= (
+            particle_type,
+            "particle_mass",
+        ) in self.data_source.ds.field_info
+        e = data.ds.quan(0.0, "erg")
+        j = data.ds.quan(0.0, "g*cm**2/s")
+        m = data.ds.quan(0.0, "g")
         if use_gas:
-            e += (data["gas", "kinetic_energy"] *
-                  data["gas", "cell_volume"]).sum(dtype=np.float64)
+            e += (data["gas", "kinetic_energy_density"] * data["gas", "volume"]).sum(
+                dtype=np.float64
+            )
             j += data["gas", "angular_momentum_magnitude"].sum(dtype=np.float64)
-            m += data["gas", "cell_mass"].sum(dtype=np.float64)
+            m += data["gas", "mass"].sum(dtype=np.float64)
         if use_particles:
-            e += (data[particle_type, "particle_velocity_magnitude"]**2 *
-                  data[particle_type, "particle_mass"]).sum(dtype=np.float64)
-            j += data[particle_type, "particle_angular_momentum_magnitude"].sum(dtype=np.float64)
+            e += (
+                data[particle_type, "particle_velocity_magnitude"] ** 2
+                * data[particle_type, "particle_mass"]
+            ).sum(dtype=np.float64)
+            j += data[particle_type, "particle_angular_momentum_magnitude"].sum(
+                dtype=np.float64
+            )
             m += data[particle_type, "particle_mass"].sum(dtype=np.float64)
         return (e, j, m)
 
@@ -753,4 +847,4 @@ class SpinParameter(DerivedQuantity):
         e = values.pop(0).sum(dtype=np.float64)
         j = values.pop(0).sum(dtype=np.float64)
         m = values.pop(0).sum(dtype=np.float64)
-        return j * np.sqrt(np.abs(e)) / m**2.5 / gravitational_constant_cgs
+        return j * np.sqrt(np.abs(e)) / m ** 2.5 / gravitational_constant_cgs
