@@ -1,12 +1,12 @@
-from yt.testing import fake_random_ds, assert_equal
 from yt.data_objects.profiles import create_profile
-from yt.visualization.plot_window import \
-    SlicePlot, \
-    ProjectionPlot, \
-    OffAxisProjectionPlot
-from yt.visualization.profile_plotter import \
-    ProfilePlot, \
-    PhasePlot
+from yt.testing import assert_equal, fake_random_ds
+from yt.visualization.plot_window import (
+    OffAxisProjectionPlot,
+    ProjectionPlot,
+    SlicePlot,
+)
+from yt.visualization.profile_plotter import PhasePlot, ProfilePlot
+
 
 def test_field_access():
     ds = fake_random_ds(16)
@@ -16,19 +16,16 @@ def test_field_access():
     cg = ds.covering_grid(0, ds.domain_left_edge, ds.domain_dimensions)
     scg = ds.smoothed_covering_grid(0, ds.domain_left_edge, ds.domain_dimensions)
     sl = ds.slice(0, ds.domain_center[0])
-    proj = ds.proj('density', 0)
-    prof = create_profile(ad, 'radius', 'density')
+    proj = ds.proj(("gas", "density"), 0)
+    prof = create_profile(ad, ("index", "radius"), ("gas", "density"))
 
     for data_object in [ad, sp, cg, scg, sl, proj, prof]:
-        assert_equal(
-            data_object['gas', 'density'],
-            data_object[ds.fields.gas.density]
-        )
+        assert_equal(data_object["gas", "density"], data_object[ds.fields.gas.density])
 
-    for field in [('gas', 'density'), ds.fields.gas.density]:
+    for field in [("gas", "density"), ds.fields.gas.density]:
         ad = ds.all_data()
-        prof = ProfilePlot(ad, 'radius', field)
-        phase = PhasePlot(ad, 'radius', field, 'cell_mass')
+        prof = ProfilePlot(ad, ("index", "radius"), field)
+        phase = PhasePlot(ad, ("index", "radius"), field, ("gas", "cell_mass"))
         s = SlicePlot(ds, 2, field)
         oas = SlicePlot(ds, [1, 1, 1], field)
         p = ProjectionPlot(ds, 2, field)
@@ -36,5 +33,5 @@ def test_field_access():
 
         for plot_object in [s, oas, p, oap, prof, phase]:
             plot_object._setup_plots()
-            if hasattr(plot_object, '_frb'):
+            if hasattr(plot_object, "_frb"):
                 plot_object._frb[field]
