@@ -1,48 +1,36 @@
-"""
-Miscellaneous FITS routines
-"""
-
-#-----------------------------------------------------------------------------
-# Copyright (c) 2013, yt Development Team.
-#
-# Distributed under the terms of the Modified BSD License.
-#
-# The full license is in the file COPYING.txt, distributed with this software.
-#-----------------------------------------------------------------------------
+import base64
+import os
+from io import BytesIO
 
 import numpy as np
-import base64
-from yt.extern.six import PY3
-from yt.fields.derived_field import ValidateSpatial
-from yt.funcs import mylog, issue_deprecation_warning
-from yt.utilities.on_demand_imports import _astropy
-from yt.units.yt_array import YTQuantity, YTArray
-if PY3:
-    from io import BytesIO as IO
-else:
-    from yt.extern.six.moves import StringIO as IO
 
-import os
+from yt.fields.derived_field import ValidateSpatial
+from yt.units.yt_array import YTArray, YTQuantity
+from yt.utilities.logger import ytLogger as mylog
+from yt.utilities.on_demand_imports import _astropy
+
 
 def _make_counts(emin, emax):
     def _counts(field, data):
-        e = data["event_energy"].in_units("keV")
+        e = data[("all", "event_energy")].in_units("keV")
         mask = np.logical_and(e >= emin, e < emax)
-        x = data["event_x"][mask]
-        y = data["event_y"][mask]
+        x = data[("all", "event_x")][mask]
+        y = data[("all", "event_y")][mask]
         z = np.ones(x.shape)
-        pos = np.array([x,y,z]).transpose()
+        pos = np.array([x, y, z]).transpose()
         img = data.deposit(pos, method="count")
         if data.has_field_parameter("sigma"):
             sigma = data.get_field_parameter("sigma")
         else:
             sigma = None
         if sigma is not None and sigma > 0.0:
-            kern = _astropy.conv.Gaussian2DKernel(stddev=sigma)
-            img[:,:,0] = _astropy.conv.convolve(img[:,:,0], kern)
+            kern = _astropy.conv.Gaussian2DKernel(x_stddev=sigma)
+            img[:, :, 0] = _astropy.conv.convolve(img[:, :, 0], kern)
         return data.ds.arr(img, "counts/pixel")
+
     return _counts
 
+
 def setup_counts_fields(ds, ebounds, ftype="gas"):
     r"""
     Create deposited image fields from X-ray count data in energy bands.
@@ -60,26 +48,30 @@ def setup_counts_fields(ds, ebounds, ftype="gas"):
     Examples
     --------
     >>> ds = yt.load("evt.fits")
-    >>> ebounds = [(0.1,2.0),(2.0,3.0)]
+    >>> ebounds = [(0.1, 2.0), (2.0, 3.0)]
     >>> setup_counts_fields(ds, ebounds)
     """
     for (emin, emax) in ebounds:
         cfunc = _make_counts(emin, emax)
-        fname = "counts_%s-%s" % (emin, emax)
-        mylog.info("Creating counts field %s." % fname)
-        ds.add_field((ftype,fname), sampling_type="cell",  function=cfunc,
-                     units="counts/pixel",
-                     validators = [ValidateSpatial()],
-                     display_name="Counts (%s-%s keV)" % (emin, emax))
+        fname = f"counts_{emin}-{emax}"
+        mylog.info("Creating counts field %s.", fname)
+        ds.add_field(
+            (ftype, fname),
+            sampling_type="cell",
+            function=cfunc,
+            units="counts/pixel",
+            validators=[ValidateSpatial()],
+            display_name=f"Counts ({emin}-{emax} keV)",
+        )
 
-def create_spectral_slabs(filename, slab_centers, slab_width,
-                          **kwargs):
+
+def create_spectral_slabs(filename, slab_centers, slab_width, **kwargs):
     r"""
     Given a dictionary of spectral slab centers and a width in
     spectral units, extract data from a spectral cube at these slab
-    centers and return a `FITSDataset` instance containing the different 
-    slabs as separate yt fields. Useful for extracting individual 
-    lines from a spectral cube and separating them out as different fields. 
+    centers and return a `FITSDataset` instance containing the different
+    slabs as separate yt fields. Useful for extracting individual
+    lines from a spectral cube and separating them out as different fields.
 
     Requires the SpectralCube (https://spectral-cube.readthedocs.io/en/latest/)
     library.
@@ -99,17 +91,21 @@ def create_spectral_slabs(filename, slab_centers, slab_width,
 
     Examples
     --------
-    >>> slab_centers = {'13CN': (218.03117, 'GHz'),
-    ...                 'CH3CH2CHO': (218.284256, 'GHz'),
-    ...                 'CH3NH2': (218.40956, 'GHz')}
+    >>> slab_centers = {
+    ...     "13CN": (218.03117, "GHz"),
+    ...     "CH3CH2CHO": (218.284256, "GHz"),
+    ...     "CH3NH2": (218.40956, "GHz"),
+    ... }
     >>> slab_width = (0.05, "GHz")
-    >>> ds = create_spectral_slabs("intensity_cube.fits", 
-    ...                            slab_centers, slab_width,
-    ...                            nan_mask=0.0)
+    >>> ds = create_spectral_slabs(
+    ...     "intensity_cube.fits", slab_centers, slab_width, nan_mask=0.0
+    ... )
     """
     from spectral_cube import SpectralCube
-    from yt.visualization.fits_image import FITSImageData
+
     from yt.frontends.fits.api import FITSDataset
+    from yt.visualization.fits_image import FITSImageData
+
     cube = SpectralCube.read(filename)
     if not isinstance(slab_width, YTQuantity):
         slab_width = YTQuantity(slab_width[0], slab_width[1])
@@ -120,16 +116,15 @@ def create_spectral_slabs(filename, slab_centers, slab_width,
             slab_center = YTQuantity(v[0], v[1])
         else:
             slab_center = v
-        mylog.info("Adding slab field %s at %g %s" %
-                   (k, slab_center.v, slab_center.units))
-        slab_lo = (slab_center-0.5*slab_width).to_astropy()
-        slab_hi = (slab_center+0.5*slab_width).to_astropy()
+        mylog.info("Adding slab field %s at %g %s", k, slab_center.v, slab_center.units)
+        slab_lo = (slab_center - 0.5 * slab_width).to_astropy()
+        slab_hi = (slab_center + 0.5 * slab_width).to_astropy()
         subcube = cube.spectral_slab(slab_lo, slab_hi)
-        slab_data[k] = YTArray(subcube.filled_data[:,:,:], field_units)
-    width = subcube.header["naxis3"]*cube.header["cdelt3"]
+        slab_data[k] = YTArray(subcube.filled_data[:, :, :], field_units)
+    width = subcube.header["naxis3"] * cube.header["cdelt3"]
     w = subcube.wcs.copy()
     w.wcs.crpix[-1] = 0.5
-    w.wcs.crval[-1] = -0.5*width
+    w.wcs.crval[-1] = -0.5 * width
     fid = FITSImageData(slab_data, wcs=w)
     for hdu in fid:
         hdu.header.pop("RESTFREQ", None)
@@ -137,6 +132,7 @@ def create_spectral_slabs(filename, slab_centers, slab_width,
     ds = FITSDataset(fid, **kwargs)
     return ds
 
+
 def ds9_region(ds, reg, obj=None, field_parameters=None):
     r"""
     Create a data container from a ds9 region file. Requires the pyregion
@@ -159,10 +155,12 @@ def ds9_region(ds, reg, obj=None, field_parameters=None):
 
     >>> ds = yt.load("m33_hi.fits")
     >>> circle_region = ds9_region(ds, "circle.reg")
-    >>> print circle_region.quantities.extrema("flux")
+    >>> print(circle_region.quantities.extrema("flux"))
     """
     import pyregion
+
     from yt.frontends.fits.api import EventsFITSDataset
+
     if os.path.exists(reg):
         r = pyregion.open(reg)
     else:
@@ -178,48 +176,40 @@ def ds9_region(ds, reg, obj=None, field_parameters=None):
         prefix = "event_"
     else:
         prefix = ""
+
     def _reg_field(field, data):
-        i = data[prefix+"xyz"[ds.lon_axis]].d.astype("int")-1
-        j = data[prefix+"xyz"[ds.lat_axis]].d.astype("int")-1
-        new_mask = mask[i,j]
-        ret = np.zeros(data[prefix+"x"].shape)
-        ret[new_mask] = 1.
+        i = data[prefix + "xyz"[ds.lon_axis]].d.astype("int") - 1
+        j = data[prefix + "xyz"[ds.lat_axis]].d.astype("int") - 1
+        new_mask = mask[i, j]
+        ret = np.zeros(data[prefix + "x"].shape)
+        ret[new_mask] = 1.0
         return ret
-    ds.add_field(("gas", reg_name), sampling_type="cell",  function=_reg_field)
+
+    ds.add_field(("gas", reg_name), sampling_type="cell", function=_reg_field)
     if obj is None:
         obj = ds.all_data()
     if field_parameters is not None:
-        for k,v in field_parameters.items():
-            obj.set_field_parameter(k,v)
-    return obj.cut_region(["obj['%s'] > 0" % (reg_name)])
+        for k, v in field_parameters.items():
+            obj.set_field_parameter(k, v)
+    return obj.cut_region([f"obj['{reg_name}'] > 0"])
 
-class PlotWindowWCS(object):
+
+class PlotWindowWCS:
     r"""
     Use AstroPy's WCSAxes class to plot celestial coordinates on the axes of a
-    on-axis PlotWindow plot. See 
+    on-axis PlotWindow plot. See
     http://docs.astropy.org/en/stable/visualization/wcsaxes/ for more details
-    on how it works under the hood. This functionality requires a version of 
-    AstroPy >= 1.3. 
+    on how it works under the hood. This functionality requires a version of
+    AstroPy >= 1.3.
 
     Parameters
     ----------
     pw : on-axis PlotWindow instance
         The PlotWindow instance to add celestial axes to.
     """
+
     def __init__(self, pw):
-        try:
-            # Attempt import from the old WCSAxes package first
-            from wcsaxes import WCSAxes
-            issue_deprecation_warning("Support for the standalone 'wcsaxes' "
-                                      "package is deprecated since its"
-                                      "functionality has been merged into"
-                                      "AstroPy, and will be removed in a "
-                                      "future release. It is recommended to "
-                                      "use the version bundled with AstroPy "
-                                      ">= 1.3.") 
-        except ImportError:
-            # Try to use the AstroPy version
-            WCSAxes = _astropy.wcsaxes.WCSAxes
+        WCSAxes = _astropy.wcsaxes.WCSAxes
 
         if pw.oblique:
             raise NotImplementedError("WCS axes are not implemented for oblique plots.")
@@ -238,10 +228,8 @@ class PlotWindowWCS(object):
             wcs = pw.ds.wcs_2d.wcs
             xax = pw.ds.coordinates.x_axis[pw.data_source.axis]
             yax = pw.ds.coordinates.y_axis[pw.data_source.axis]
-            xlabel = "%s (%s)" % (wcs.ctype[xax].split("-")[0],
-                                  wcs.cunit[xax])
-            ylabel = "%s (%s)" % (wcs.ctype[yax].split("-")[0],
-                                  wcs.cunit[yax])
+            xlabel = f"{wcs.ctype[xax].split('-')[0]} ({wcs.cunit[xax]})"
+            ylabel = f"{wcs.ctype[yax].split('-')[0]} ({wcs.cunit[yax]})"
             fp = pw._font_properties
             wcs_ax.coords[0].set_axislabel(xlabel, fontproperties=fp, minpad=0.5)
             wcs_ax.coords[1].set_axislabel(ylabel, fontproperties=fp, minpad=0.4)
@@ -281,13 +269,16 @@ class PlotWindowWCS(object):
 
     def _repr_html_(self):
         from yt.visualization._mpl_imports import FigureCanvasAgg
-        ret = ''
-        for k, v in self.plots.items():
+
+        ret = ""
+        for v in self.plots.values():
             canvas = FigureCanvasAgg(v)
-            f = IO()
+            f = BytesIO()
             canvas.print_figure(f)
             f.seek(0)
             img = base64.b64encode(f.read()).decode()
-            ret += r'<img style="max-width:100%%;max-height:100%%;" ' \
-                   r'src="data:image/png;base64,%s"><br>' % img
+            ret += (
+                r'<img style="max-width:100%%;max-height:100%%;" '
+                r'src="data:image/png;base64,%s"><br>' % img
+            )
         return ret
