@@ -1,25 +1,7 @@
-"""
-SPH fields
+from yt.fields.field_info_container import FieldInfoContainer
+from yt.fields.species_fields import setup_species_fields
 
 
-
-
-"""
-from __future__ import absolute_import
-
-#-----------------------------------------------------------------------------
-# Copyright (c) 2013, yt Development Team.
-#
-# Distributed under the terms of the Modified BSD License.
-#
-# The full license is in the file COPYING.txt, distributed with this software.
-#-----------------------------------------------------------------------------
-
-from yt.fields.field_info_container import \
-    FieldInfoContainer
-from yt.fields.species_fields import \
-    setup_species_fields
-
 class SPHFieldInfo(FieldInfoContainer):
     known_other_fields = ()
 
@@ -30,7 +12,7 @@ class SPHFieldInfo(FieldInfoContainer):
         ("Velocity", ("code_velocity", ["particle_velocity"], None)),
         ("Velocities", ("code_velocity", ["particle_velocity"], None)),
         ("ParticleIDs", ("", ["particle_index"], None)),
-        ("InternalEnergy", ("code_specific_energy", ["thermal_energy"], None)),
+        ("InternalEnergy", ("code_specific_energy", ["specific_thermal_energy"], None)),
         ("SmoothingLength", ("code_length", ["smoothing_length"], None)),
         ("Density", ("code_mass / code_length**3", ["density"], None)),
         ("MaximumTemperature", ("K", [], None)),
@@ -39,11 +21,18 @@ class SPHFieldInfo(FieldInfoContainer):
         ("Metals", ("code_metallicity", ["metallicity"], None)),
         ("Metallicity", ("code_metallicity", ["metallicity"], None)),
         ("Phi", ("code_length", [], None)),
+        ("Potential", ("code_velocity**2", ["gravitational_potential"], None)),
         ("StarFormationRate", ("Msun / yr", [], None)),
         ("FormationTime", ("code_time", ["creation_time"], None)),
         ("Metallicity_00", ("", ["metallicity"], None)),
+        ("InitialMass", ("code_mass", [], None)),
+        ("TrueMass", ("code_mass", [], None)),
+        ("ElevenMetalMasses", ("code_mass", [], None)),
     )
 
     def setup_particle_fields(self, ptype, *args, **kwargs):
-        super(SPHFieldInfo, self).setup_particle_fields(ptype, *args, **kwargs)
+        super().setup_particle_fields(ptype, *args, **kwargs)
         setup_species_fields(self, ptype)
+
+    def setup_fluid_index_fields(self):
+        pass
