@@ -1,38 +1,24 @@
-"""
-Geometry container base class.
-
-
-
-
-"""
-
-#-----------------------------------------------------------------------------
-# Copyright (c) 2013, yt Development Team.
-#
-# Distributed under the terms of the Modified BSD License.
-#
-# The full license is in the file COPYING.txt, distributed with this software.
-#-----------------------------------------------------------------------------
-
+import abc
 import os
-from yt.extern.six.moves import cPickle
 import weakref
-from yt.utilities.on_demand_imports import _h5py as h5py
+
 import numpy as np
 
 from yt.config import ytcfg
-from yt.funcs import iterable
-from yt.units.yt_array import \
-    YTArray, uconcatenate
+from yt.units.yt_array import YTArray, uconcatenate
+from yt.utilities.exceptions import YTFieldNotFound
 from yt.utilities.io_handler import io_registry
 from yt.utilities.logger import ytLogger as mylog
-from yt.utilities.parallel_tools.parallel_analysis_interface import \
-    ParallelAnalysisInterface, parallel_root_only
-from yt.utilities.exceptions import YTFieldNotFound
+from yt.utilities.on_demand_imports import _h5py as h5py
+from yt.utilities.parallel_tools.parallel_analysis_interface import (
+    ParallelAnalysisInterface,
+    parallel_root_only,
+)
 
-class Index(ParallelAnalysisInterface):
+
+class Index(ParallelAnalysisInterface, abc.ABC):
     """The base index class"""
-    _global_mesh = True
+
     _unsupported_objects = ()
     _index_properties = ()
 
@@ -57,6 +43,10 @@ class Index(ParallelAnalysisInterface):
         mylog.debug("Detecting fields.")
         self._detect_output_fields()
 
+    @abc.abstractmethod
+    def _detect_output_fields(self):
+        pass
+
     def _initialize_state_variables(self):
         self._parallel_locking = False
         self._data_file = None
@@ -64,18 +54,19 @@ class Index(ParallelAnalysisInterface):
         self.num_grids = None
 
     def _initialize_data_storage(self):
-        if not ytcfg.getboolean('yt','serialize'): return
+        if not ytcfg.get("yt", "serialize"):
+            return
         fn = self.ds.storage_filename
         if fn is None:
-            if os.path.isfile(os.path.join(self.directory,
-                                "%s.yt" % self.ds.unique_identifier)):
-                fn = os.path.join(self.directory,"%s.yt" % self.ds.unique_identifier)
+            if os.path.isfile(
+                os.path.join(self.directory, f"{self.ds.unique_identifier}.yt")
+            ):
+                fn = os.path.join(self.directory, f"{self.ds.unique_identifier}.yt")
             else:
-                fn = os.path.join(self.directory,
-                        "%s.yt" % self.dataset.basename)
+                fn = os.path.join(self.directory, f"{self.dataset.basename}.yt")
         dir_to_check = os.path.dirname(fn)
-        if dir_to_check == '':
-            dir_to_check = '.'
+        if dir_to_check == "":
+            dir_to_check = "."
         # We have four options:
         #    Writeable, does not exist      : create, open as append
         #    Writeable, does exist          : open as append
@@ -86,42 +77,48 @@ class Index(ParallelAnalysisInterface):
             writeable = os.access(dir_to_check, os.W_OK)
         else:
             writeable = os.access(fn, os.W_OK)
-        writeable = writeable and not ytcfg.getboolean('yt','onlydeserialize')
+        writeable = writeable and not ytcfg.get("yt", "only_deserialize")
         # We now have our conditional stuff
         self.comm.barrier()
-        if not writeable and not exists: return
+        if not writeable and not exists:
+            return
         if writeable:
             try:
-                if not exists: self.__create_data_file(fn)
-                self._data_mode = 'a'
-            except IOError:
+                if not exists:
+                    self.__create_data_file(fn)
+                self._data_mode = "a"
+            except OSError:
                 self._data_mode = None
                 return
         else:
-            self._data_mode = 'r'
+            self._data_mode = "r"
 
         self.__data_filename = fn
-        self._data_file = h5py.File(fn, self._data_mode)
+        self._data_file = h5py.File(fn, mode=self._data_mode)
 
     def __create_data_file(self, fn):
         # Note that this used to be parallel_root_only; it no longer is,
         # because we have better logic to decide who owns the file.
-        f = h5py.File(fn, 'a')
+        f = h5py.File(fn, mode="a")
         f.close()
 
     def _setup_data_io(self):
-        if getattr(self, "io", None) is not None: return
+        if getattr(self, "io", None) is not None:
+            return
         self.io = io_registry[self.dataset_type](self.dataset)
 
     @parallel_root_only
-    def save_data(self, array, node, name, set_attr=None, force=False, passthrough = False):
+    def save_data(
+        self, array, node, name, set_attr=None, force=False, passthrough=False
+    ):
         """
         Arbitrary numpy data will be saved to the region in the datafile
         described by *node* and *name*.  If data file does not exist, it throws
         no error and simply does not save.
         """
 
-        if self._data_mode != 'a': return
+        if self._data_mode != "a":
+            return
         try:
             node_loc = self._data_file[node]
             if name in node_loc and force:
@@ -129,42 +126,24 @@ class Index(ParallelAnalysisInterface):
                 del self._data_file[node][name]
             elif name in node_loc and passthrough:
                 return
-        except Exception: pass
-        myGroup = self._data_file['/']
-        for q in node.split('/'):
-            if q: myGroup = myGroup.require_group(q)
-        arr = myGroup.create_dataset(name,data=array)
+        except Exception:
+            pass
+        myGroup = self._data_file["/"]
+        for q in node.split("/"):
+            if q:
+                myGroup = myGroup.require_group(q)
+        arr = myGroup.create_dataset(name, data=array)
         if set_attr is not None:
-            for i, j in set_attr.items(): arr.attrs[i] = j
+            for i, j in set_attr.items():
+                arr.attrs[i] = j
         self._data_file.flush()
 
     def _reload_data_file(self, *args, **kwargs):
-        if self._data_file is None: return
+        if self._data_file is None:
+            return
         self._data_file.close()
         del self._data_file
-        self._data_file = h5py.File(self.__data_filename, self._data_mode)
-
-    def save_object(self, obj, name):
-        """
-        Save an object (*obj*) to the data_file using the Pickle protocol,
-        under the name *name* on the node /Objects.
-        """
-        s = cPickle.dumps(obj, protocol=-1)
-        self.save_data(np.array(s, dtype='c'), "/Objects", name, force = True)
-
-    def load_object(self, name):
-        """
-        Load and return and object from the data_file using the Pickle protocol,
-        under the name *name* on the node /Objects.
-        """
-        obj = self.get_data("/Objects", name)
-        if obj is None:
-            return
-        obj = cPickle.loads(obj.value)
-        if iterable(obj) and len(obj) == 2:
-            obj = obj[1] # Just the object, not the ds
-        if hasattr(obj, '_fix_pickle'): obj._fix_pickle()
-        return obj
+        self._data_file = h5py.File(self.__data_filename, mode=self._data_mode)
 
     def get_data(self, node, name):
         """
@@ -173,10 +152,11 @@ class Index(ParallelAnalysisInterface):
         """
         if self._data_file is None:
             return None
-        if node[0] != "/": node = "/%s" % node
+        if node[0] != "/":
+            node = f"/{node}"
 
-        myGroup = self._data_file['/']
-        for group in node.split('/'):
+        myGroup = self._data_file["/"]
+        for group in node.split("/"):
             if group:
                 if group not in myGroup:
                     return None
@@ -184,7 +164,7 @@ class Index(ParallelAnalysisInterface):
         if name not in myGroup:
             return None
 
-        full_name = "%s/%s" % (node, name)
+        full_name = f"{node}/{name}"
         try:
             return self._data_file[full_name][:]
         except TypeError:
@@ -206,28 +186,33 @@ class Index(ParallelAnalysisInterface):
         for ftype, fname in fields:
             if fname in self.field_list or (ftype, fname) in self.field_list:
                 fields_to_read.append((ftype, fname))
-            elif fname in self.ds.derived_field_list or (ftype, fname) in self.ds.derived_field_list:
+            elif (
+                fname in self.ds.derived_field_list
+                or (ftype, fname) in self.ds.derived_field_list
+            ):
                 fields_to_generate.append((ftype, fname))
             else:
-                raise YTFieldNotFound((ftype,fname), self.ds)
+                raise YTFieldNotFound((ftype, fname), self.ds)
         return fields_to_read, fields_to_generate
 
-    def _read_particle_fields(self, fields, dobj, chunk = None):
-        if len(fields) == 0: return {}, []
+    def _read_particle_fields(self, fields, dobj, chunk=None):
+        if len(fields) == 0:
+            return {}, []
         fields_to_read, fields_to_generate = self._split_fields(fields)
         if len(fields_to_read) == 0:
             return {}, fields_to_generate
         selector = dobj.selector
         if chunk is None:
             self._identify_base_chunk(dobj)
+        chunks = self._chunk_io(dobj, cache=False)
         fields_to_return = self.io._read_particle_selection(
-            self._chunk_io(dobj, cache = False),
-            selector,
-            fields_to_read)
+            chunks, selector, fields_to_read
+        )
         return fields_to_return, fields_to_generate
 
-    def _read_fluid_fields(self, fields, dobj, chunk = None):
-        if len(fields) == 0: return {}, []
+    def _read_fluid_fields(self, fields, dobj, chunk=None):
+        if len(fields) == 0:
+            return {}, []
         fields_to_read, fields_to_generate = self._split_fields(fields)
         if len(fields_to_read) == 0:
             return {}, fields_to_generate
@@ -238,13 +223,11 @@ class Index(ParallelAnalysisInterface):
         else:
             chunk_size = chunk.data_size
         fields_to_return = self.io._read_fluid_selection(
-            self._chunk_io(dobj),
-            selector,
-            fields_to_read,
-            chunk_size)
+            self._chunk_io(dobj), selector, fields_to_read, chunk_size
+        )
         return fields_to_return, fields_to_generate
 
-    def _chunk(self, dobj, chunking_style, ngz = 0, **kwargs):
+    def _chunk(self, dobj, chunking_style, ngz=0, **kwargs):
         # A chunk is either None or (grids, size)
         if dobj._current_chunk is None:
             self._identify_base_chunk(dobj)
@@ -259,8 +242,12 @@ class Index(ParallelAnalysisInterface):
         else:
             raise NotImplementedError
 
+
 def cached_property(func):
-    n = '_%s' % func.__name__
+    # TODO: remove this once minimal supported version of Python reaches 3.8
+    # and replace with functools.cached
+    n = f"_{func.__name__}"
+
     def cached_func(self):
         if self._cache and getattr(self, n, None) is not None:
             return getattr(self, n)
@@ -272,12 +259,21 @@ def cached_property(func):
 
             setattr(self, n, tr)
         return tr
+
     return property(cached_func)
 
-class YTDataChunk(object):
 
-    def __init__(self, dobj, chunk_type, objs, data_size = None,
-                 field_type = None, cache = False, fast_index = None):
+class YTDataChunk:
+    def __init__(
+        self,
+        dobj,
+        chunk_type,
+        objs,
+        data_size=None,
+        field_type=None,
+        cache=False,
+        fast_index=None,
+    ):
         self.dobj = dobj
         self.chunk_type = chunk_type
         self.objs = objs
@@ -289,7 +285,7 @@ class YTDataChunk(object):
     def _accumulate_values(self, method):
         # We call this generically.  It's somewhat slower, since we're doing
         # costly getattr functions, but this allows us to generalize.
-        mname = "select_%s" % method
+        mname = f"select_{method}"
         arrs = []
         for obj in self._fast_index or self.objs:
             f = getattr(obj, mname)
@@ -305,72 +301,72 @@ class YTDataChunk(object):
     @cached_property
     def fcoords(self):
         if self._fast_index is not None:
-            ci = self._fast_index.select_fcoords(
-                self.dobj.selector, self.data_size)
-            ci = YTArray(ci, input_units = "code_length",
-                         registry = self.dobj.ds.unit_registry)
+            ci = self._fast_index.select_fcoords(self.dobj.selector, self.data_size)
+            ci = YTArray(ci, units="code_length", registry=self.dobj.ds.unit_registry)
+            return ci
+        ci = np.empty((self.data_size, 3), dtype="float64")
+        ci = YTArray(ci, units="code_length", registry=self.dobj.ds.unit_registry)
+        if self.data_size == 0:
             return ci
-        ci = np.empty((self.data_size, 3), dtype='float64')
-        ci = YTArray(ci, input_units = "code_length",
-                     registry = self.dobj.ds.unit_registry)
-        if self.data_size == 0: return ci
         ind = 0
         for obj in self._fast_index or self.objs:
             c = obj.select_fcoords(self.dobj)
-            if c.shape[0] == 0: continue
-            ci[ind:ind+c.shape[0], :] = c
+            if c.shape[0] == 0:
+                continue
+            ci[ind : ind + c.shape[0], :] = c
             ind += c.shape[0]
         return ci
 
     @cached_property
     def icoords(self):
         if self._fast_index is not None:
-            ci = self._fast_index.select_icoords(
-                self.dobj.selector, self.data_size)
+            ci = self._fast_index.select_icoords(self.dobj.selector, self.data_size)
+            return ci
+        ci = np.empty((self.data_size, 3), dtype="int64")
+        if self.data_size == 0:
             return ci
-        ci = np.empty((self.data_size, 3), dtype='int64')
-        if self.data_size == 0: return ci
         ind = 0
         for obj in self._fast_index or self.objs:
             c = obj.select_icoords(self.dobj)
-            if c.shape[0] == 0: continue
-            ci[ind:ind+c.shape[0], :] = c
+            if c.shape[0] == 0:
+                continue
+            ci[ind : ind + c.shape[0], :] = c
             ind += c.shape[0]
         return ci
 
     @cached_property
     def fwidth(self):
         if self._fast_index is not None:
-            ci = self._fast_index.select_fwidth(
-                self.dobj.selector, self.data_size)
-            ci = YTArray(ci, input_units = "code_length",
-                         registry = self.dobj.ds.unit_registry)
+            ci = self._fast_index.select_fwidth(self.dobj.selector, self.data_size)
+            ci = YTArray(ci, units="code_length", registry=self.dobj.ds.unit_registry)
+            return ci
+        ci = np.empty((self.data_size, 3), dtype="float64")
+        ci = YTArray(ci, units="code_length", registry=self.dobj.ds.unit_registry)
+        if self.data_size == 0:
             return ci
-        ci = np.empty((self.data_size, 3), dtype='float64')
-        ci = YTArray(ci, input_units = "code_length",
-                     registry = self.dobj.ds.unit_registry)
-        if self.data_size == 0: return ci
         ind = 0
         for obj in self._fast_index or self.objs:
             c = obj.select_fwidth(self.dobj)
-            if c.shape[0] == 0: continue
-            ci[ind:ind+c.shape[0], :] = c
+            if c.shape[0] == 0:
+                continue
+            ci[ind : ind + c.shape[0], :] = c
             ind += c.shape[0]
         return ci
 
     @cached_property
     def ires(self):
         if self._fast_index is not None:
-            ci = self._fast_index.select_ires(
-                self.dobj.selector, self.data_size)
+            ci = self._fast_index.select_ires(self.dobj.selector, self.data_size)
+            return ci
+        ci = np.empty(self.data_size, dtype="int64")
+        if self.data_size == 0:
             return ci
-        ci = np.empty(self.data_size, dtype='int64')
-        if self.data_size == 0: return ci
         ind = 0
         for obj in self._fast_index or self.objs:
             c = obj.select_ires(self.dobj)
-            if c.shape == 0: continue
-            ci[ind:ind+c.size] = c
+            if c.shape == 0:
+                continue
+            ci[ind : ind + c.size] = c
             ind += c.size
         return ci
 
@@ -381,16 +377,18 @@ class YTDataChunk(object):
 
     @cached_property
     def dtcoords(self):
-        ct = np.empty(self.data_size, dtype='float64')
-        cdt = np.empty(self.data_size, dtype='float64')
-        self._tcoords = ct # Se this for tcoords
-        if self.data_size == 0: return cdt
+        ct = np.empty(self.data_size, dtype="float64")
+        cdt = np.empty(self.data_size, dtype="float64")
+        self._tcoords = ct  # Se this for tcoords
+        if self.data_size == 0:
+            return cdt
         ind = 0
         for obj in self._fast_index or self.objs:
             gdt, gt = obj.select_tcoords(self.dobj)
-            if gt.size == 0: continue
-            ct[ind:ind+gt.size] = gt
-            cdt[ind:ind+gdt.size] = gdt
+            if gt.size == 0:
+                continue
+            ct[ind : ind + gt.size] = gt
+            cdt[ind : ind + gdt.size] = gdt
             ind += gt.size
         return cdt
 
@@ -398,22 +396,22 @@ class YTDataChunk(object):
     def fcoords_vertex(self):
         nodes_per_elem = self.dobj.index.meshes[0].connectivity_indices.shape[1]
         dim = self.dobj.ds.dimensionality
-        ci = np.empty((self.data_size, nodes_per_elem, dim), dtype='float64')
-        ci = YTArray(ci, input_units = "code_length",
-                     registry = self.dobj.ds.unit_registry)
-        if self.data_size == 0: return ci
+        ci = np.empty((self.data_size, nodes_per_elem, dim), dtype="float64")
+        ci = YTArray(ci, units="code_length", registry=self.dobj.ds.unit_registry)
+        if self.data_size == 0:
+            return ci
         ind = 0
         for obj in self.objs:
             c = obj.select_fcoords_vertex(self.dobj)
-            if c.shape[0] == 0: continue
-            ci[ind:ind+c.shape[0], :, :] = c
+            if c.shape[0] == 0:
+                continue
+            ci[ind : ind + c.shape[0], :, :] = c
             ind += c.shape[0]
         return ci
 
 
-class ChunkDataCache(object):
-    def __init__(self, base_iter, preload_fields, geometry_handler,
-                 max_length = 256):
+class ChunkDataCache:
+    def __init__(self, base_iter, preload_fields, geometry_handler, max_length=256):
         # At some point, max_length should instead become a heuristic function,
         # potentially looking at estimated memory usage.  Note that this never
         # initializes the iterator; it assumes the iterator is already created,
@@ -429,27 +427,28 @@ class ChunkDataCache(object):
         return self
 
     def __next__(self):
-        return self.next()
-
-    def next(self):
         if len(self.queue) == 0:
-            for i in range(self.max_length):
+            for _ in range(self.max_length):
                 try:
                     self.queue.append(next(self.base_iter))
                 except StopIteration:
                     break
             # If it's still zero ...
-            if len(self.queue) == 0: raise StopIteration
+            if len(self.queue) == 0:
+                raise StopIteration
             chunk = YTDataChunk(None, "cache", self.queue, cache=False)
-            self.cache = self.geometry_handler.io._read_chunk_data(
-                chunk, self.preload_fields) or {}
+            self.cache = (
+                self.geometry_handler.io._read_chunk_data(chunk, self.preload_fields)
+                or {}
+            )
         g = self.queue.pop(0)
         g._initialize_cache(self.cache.pop(g.id, {}))
         return g
 
+
 def is_curvilinear(geo):
     # tell geometry is curvilinear or not
     if geo in ["polar", "cylindrical", "spherical"]:
         return True
     else:
-        return False
\ No newline at end of file
+        return False
