@@ -1,43 +1,28 @@
-"""
-Very simple convenience function for importing all the modules, setting up
-the namespace and getting the last argument on the command line.
-
-
-
-"""
-
-#-----------------------------------------------------------------------------
-# Copyright (c) 2013, yt Development Team.
-#
-# Distributed under the terms of the Modified BSD License.
-#
-# The full license is in the file COPYING.txt, distributed with this software.
-#-----------------------------------------------------------------------------
-
-from __future__ import absolute_import
-
 #
 # ALL IMPORTS GO HERE
 #
 
 import os
-from yt import *
+
+import numpy as np
 
 # This next item will handle most of the actual startup procedures, but it will
 # also attempt to parse the command line and set up the global state of various
 # operations.  The variable unparsed_args is not used internally but is
 # provided as a convenience for users who wish to parse arguments in scripts.
-# https://mail.python.org/mm3/archives/list/yt-dev@python.org/thread/L6AQPJ3OIMJC5SNKVM7CJG32YVQZRJWA/
+# https://mail.python.org/archives/list/yt-dev@python.org/thread/L6AQPJ3OIMJC5SNKVM7CJG32YVQZRJWA/
 import yt.startup_tasks as __startup_tasks
+from yt import *
+from yt.config import ytcfg, ytcfg_defaults
+from yt.utilities.logger import _level
+
 unparsed_args = __startup_tasks.unparsed_args
 
-from yt.config import ytcfg, ytcfg_defaults
 
-from yt.utilities.logger import level as __level
-if __level >= int(ytcfg_defaults["loglevel"]):
+if _level >= int(ytcfg_defaults["yt"]["log_level"]):
     # This won't get displayed.
     mylog.debug("Turning off NumPy error reporting")
-    np.seterr(all = 'ignore')
+    np.seterr(all="ignore")
 
 # We load plugins.  Keep in mind, this can be fairly dangerous -
 # the primary purpose is to allow people to have a set of functions
@@ -45,5 +30,5 @@ if __level >= int(ytcfg_defaults["loglevel"]):
 # This way, other command-line tools can be used very simply.
 # Unfortunately, for now, I think the easiest and simplest way of doing
 # this is also the most dangerous way.
-if ytcfg.getboolean("yt","loadfieldplugins"):
+if ytcfg.get("yt", "load_field_plugins"):
     enable_plugins()
