@@ -1,39 +1,22 @@
-"""
-Cosmology calculator.
-Cosmology calculator based originally on http://www.kempner.net/cosmic.php 
-and featuring time and redshift conversion functions from Enzo.
-
-"""
-
-#-----------------------------------------------------------------------------
-# Copyright (c) yt Development Team. All rights reserved.
-#
-# Distributed under the terms of the Modified BSD License.
-#
-# The full license is in the file COPYING.txt, distributed with this software.
-#-----------------------------------------------------------------------------
-
 import functools
+
 import numpy as np
 
-from yt.funcs import \
-     issue_deprecation_warning
 from yt.units import dimensions
-from yt.units.unit_registry import \
-     UnitRegistry
-from yt.units.yt_array import \
-     YTArray, \
-     YTQuantity
+from yt.units.unit_object import Unit
+from yt.units.unit_registry import UnitRegistry
+from yt.units.yt_array import YTArray, YTQuantity
+from yt.utilities.physical_constants import (
+    gravitational_constant_cgs as G,
+    speed_of_light_cgs,
+)
 
-from yt.utilities.physical_constants import \
-     gravitational_constant_cgs as G, \
-     speed_of_light_cgs
 
-class Cosmology(object):
+class Cosmology:
     r"""
     Create a cosmology calculator to compute cosmological distances and times.
 
-    For an explanation of the various cosmological measures, see, for example 
+    For an explanation of the various cosmological measures, see, for example
     Hogg (1999, https://arxiv.org/abs/astro-ph/9905116).
 
     WARNING: Cosmological distance calculations return values that are either
@@ -48,15 +31,15 @@ class Cosmology(object):
     hubble_constant : float
         The Hubble parameter at redshift zero in units of 100 km/s/Mpc.
         Default: 0.71.
-    omega_matter : the fraction of the energy density of the Universe in 
+    omega_matter : the fraction of the energy density of the Universe in
         matter at redshift zero.
         Default: 0.27.
-    omega_lambda : the fraction of the energy density of the Universe in 
+    omega_lambda : the fraction of the energy density of the Universe in
         a cosmological constant.
         Default: 0.73.
     omega_radiation : the fraction of the energy density of the Universe in
         relativistic matter at redshift zero.
-    omega_curvature : the fraction of the energy density of the Universe in 
+    omega_curvature : the fraction of the energy density of the Universe in
         curvature.
         Default: 0.0.
     unit_system : :class:`yt.units.unit_systems.UnitSystem`, optional
@@ -72,7 +55,7 @@ class Cosmology(object):
         Cosmological constant case corresponds to w_0 = -1.
     w_a : float, optional
         See w_0. w_a is the derivative of w(a) evaluated at a = 1. Cosmological
-        constant case corresponds to w_a = 0. Default is None. 
+        constant case corresponds to w_a = 0. Default is None.
 
     Examples
     --------
@@ -82,32 +65,42 @@ class Cosmology(object):
     >>> print(co.t_from_z(0.0).in_units("Gyr"))
 
     """
-    def __init__(self, hubble_constant = 0.71,
-                 omega_matter = 0.27,
-                 omega_lambda = 0.73,
-                 omega_radiation = 0.0,
-                 omega_curvature = 0.0,
-                 unit_registry = None,
-                 unit_system = "cgs",
-                 use_dark_factor = False,
-                 w_0 = -1.0,
-                 w_a = 0.0):
+
+    def __init__(
+        self,
+        hubble_constant=0.71,
+        omega_matter=0.27,
+        omega_lambda=0.73,
+        omega_radiation=0.0,
+        omega_curvature=0.0,
+        unit_registry=None,
+        unit_system="cgs",
+        use_dark_factor=False,
+        w_0=-1.0,
+        w_a=0.0,
+    ):
         self.omega_matter = float(omega_matter)
         self.omega_radiation = float(omega_radiation)
         self.omega_lambda = float(omega_lambda)
         self.omega_curvature = float(omega_curvature)
         if unit_registry is None:
-            unit_registry = UnitRegistry()
-            unit_registry.modify("h", hubble_constant)
+            unit_registry = UnitRegistry(unit_system=unit_system)
+            unit_registry.add("h", hubble_constant, dimensions.dimensionless, r"h")
             for my_unit in ["m", "pc", "AU", "au"]:
-                new_unit = "%scm" % my_unit
+                new_unit = f"{my_unit}cm"
+                my_u = Unit(my_unit, registry=unit_registry)
                 # technically not true, but distances here are actually comoving
-                unit_registry.add(new_unit, unit_registry.lut[my_unit][0],
-                                  dimensions.length, "\\rm{%s}/(1+z)" % my_unit)
+                unit_registry.add(
+                    new_unit,
+                    my_u.base_value,
+                    dimensions.length,
+                    "\\rm{%s}/(1+z)" % my_unit,
+                    prefixable=True,
+                )
         self.unit_registry = unit_registry
         self.hubble_constant = self.quan(hubble_constant, "100*km/s/Mpc")
         self.unit_system = unit_system
-        
+
         # For non-standard dark energy. If false, use default cosmological constant
         # This only affects the expansion_factor function.
         self.use_dark_factor = use_dark_factor
@@ -116,15 +109,16 @@ class Cosmology(object):
 
     def hubble_distance(self):
         r"""
-        The distance corresponding to c / h, where c is the speed of light 
+        The distance corresponding to c / h, where c is the speed of light
         and h is the Hubble parameter in units of 1 / time.
         """
-        return self.quan(speed_of_light_cgs /
-                         self.hubble_constant).in_base(self.unit_system)
+        return self.quan(speed_of_light_cgs / self.hubble_constant).in_base(
+            self.unit_system
+        )
 
     def comoving_radial_distance(self, z_i, z_f):
         r"""
-        The comoving distance along the line of sight to on object at redshift, 
+        The comoving distance along the line of sight to on object at redshift,
         z_f, viewed at a redshift, z_i.
 
         Parameters
@@ -139,16 +133,17 @@ class Cosmology(object):
 
         >>> from yt.utilities.cosmology import Cosmology
         >>> co = Cosmology()
-        >>> print(co.comoving_radial_distance(0., 1.).in_units("Mpccm"))
-        
+        >>> print(co.comoving_radial_distance(0.0, 1.0).in_units("Mpccm"))
+
         """
-        return (self.hubble_distance() *
-                trapzint(self.inverse_expansion_factor, z_i, z_f)).in_base(self.unit_system)
+        return (
+            self.hubble_distance() * trapzint(self.inverse_expansion_factor, z_i, z_f)
+        ).in_base(self.unit_system)
 
     def comoving_transverse_distance(self, z_i, z_f):
         r"""
-        When multiplied by some angle, the distance between two objects 
-        observed at redshift, z_f, with an angular separation given by that 
+        When multiplied by some angle, the distance between two objects
+        observed at redshift, z_f, with an angular separation given by that
         angle, viewed by an observer at redshift, z_i (Hogg 1999).
 
         Parameters
@@ -163,29 +158,38 @@ class Cosmology(object):
 
         >>> from yt.utilities.cosmology import Cosmology
         >>> co = Cosmology()
-        >>> print(co.comoving_transverse_distance(0., 1.).in_units("Mpccm"))
-        
+        >>> print(co.comoving_transverse_distance(0.0, 1.0).in_units("Mpccm"))
+
         """
-        if (self.omega_curvature > 0):
-            return (self.hubble_distance() / np.sqrt(self.omega_curvature) * 
-                    np.sinh(np.sqrt(self.omega_curvature) * 
-                            self.comoving_radial_distance(z_i, z_f) /
-                            self.hubble_distance())).in_base(self.unit_system)
-        elif (self.omega_curvature < 0):
-            return (self.hubble_distance() /
-                    np.sqrt(np.fabs(self.omega_curvature)) * 
-                    np.sin(np.sqrt(np.fabs(self.omega_curvature)) * 
-                           self.comoving_radial_distance(z_i, z_f) /
-                           self.hubble_distance())).in_base(self.unit_system)
+        if self.omega_curvature > 0:
+            return (
+                self.hubble_distance()
+                / np.sqrt(self.omega_curvature)
+                * np.sinh(
+                    np.sqrt(self.omega_curvature)
+                    * self.comoving_radial_distance(z_i, z_f)
+                    / self.hubble_distance()
+                )
+            ).in_base(self.unit_system)
+        elif self.omega_curvature < 0:
+            return (
+                self.hubble_distance()
+                / np.sqrt(np.fabs(self.omega_curvature))
+                * np.sin(
+                    np.sqrt(np.fabs(self.omega_curvature))
+                    * self.comoving_radial_distance(z_i, z_f)
+                    / self.hubble_distance()
+                )
+            ).in_base(self.unit_system)
         else:
             return self.comoving_radial_distance(z_i, z_f)
 
     def comoving_volume(self, z_i, z_f):
         r"""
-        "The comoving volume is the volume measure in which number densities 
-        of non-evolving objects locked into Hubble flow are constant with 
+        "The comoving volume is the volume measure in which number densities
+        of non-evolving objects locked into Hubble flow are constant with
         redshift." -- Hogg (1999)
-        
+
         Parameters
         ----------
         z_i : float
@@ -198,41 +202,67 @@ class Cosmology(object):
 
         >>> from yt.utilities.cosmology import Cosmology
         >>> co = Cosmology()
-        >>> print(co.comoving_volume(0., 1.).in_units("Gpccm**3"))
+        >>> print(co.comoving_volume(0.0, 1.0).in_units("Gpccm**3"))
 
         """
-        if (self.omega_curvature > 1e-10):
-            return (2 * np.pi * np.power(self.hubble_distance(), 3) /
-                     self.omega_curvature * 
-                     (self.comoving_transverse_distance(z_i, z_f) /
-                      self.hubble_distance() * 
-                      np.sqrt(1 + self.omega_curvature * 
-                           np.sqrt(self.comoving_transverse_distance(z_i, z_f) /
-                               self.hubble_distance())) - 
-                      np.sinh(np.fabs(self.omega_curvature) * 
-                            self.comoving_transverse_distance(z_i, z_f) /
-                            self.hubble_distance()) /
-                            np.sqrt(self.omega_curvature))).in_base(self.unit_system)
-        elif (self.omega_curvature < -1e-10):
-            return (2 * np.pi * np.power(self.hubble_distance(), 3) /
-                     np.fabs(self.omega_curvature) * 
-                     (self.comoving_transverse_distance(z_i, z_f) /
-                      self.hubble_distance() * 
-                      np.sqrt(1 + self.omega_curvature * 
-                           np.sqrt(self.comoving_transverse_distance(z_i, z_f) /
-                               self.hubble_distance())) - 
-                      np.arcsin(np.fabs(self.omega_curvature) * 
-                           self.comoving_transverse_distance(z_i, z_f) /
-                           self.hubble_distance()) /
-                      np.sqrt(np.fabs(self.omega_curvature)))).in_base(self.unit_system)
+        if self.omega_curvature > 1e-10:
+            return (
+                2
+                * np.pi
+                * np.power(self.hubble_distance(), 3)
+                / self.omega_curvature
+                * (
+                    self.comoving_transverse_distance(z_i, z_f)
+                    / self.hubble_distance()
+                    * np.sqrt(
+                        1
+                        + self.omega_curvature
+                        * np.sqrt(
+                            self.comoving_transverse_distance(z_i, z_f)
+                            / self.hubble_distance()
+                        )
+                    )
+                    - np.sinh(
+                        np.fabs(self.omega_curvature)
+                        * self.comoving_transverse_distance(z_i, z_f)
+                        / self.hubble_distance()
+                    )
+                    / np.sqrt(self.omega_curvature)
+                )
+            ).in_base(self.unit_system)
+        elif self.omega_curvature < -1e-10:
+            return (
+                2
+                * np.pi
+                * np.power(self.hubble_distance(), 3)
+                / np.fabs(self.omega_curvature)
+                * (
+                    self.comoving_transverse_distance(z_i, z_f)
+                    / self.hubble_distance()
+                    * np.sqrt(
+                        1
+                        + self.omega_curvature
+                        * np.sqrt(
+                            self.comoving_transverse_distance(z_i, z_f)
+                            / self.hubble_distance()
+                        )
+                    )
+                    - np.arcsin(
+                        np.fabs(self.omega_curvature)
+                        * self.comoving_transverse_distance(z_i, z_f)
+                        / self.hubble_distance()
+                    )
+                    / np.sqrt(np.fabs(self.omega_curvature))
+                )
+            ).in_base(self.unit_system)
         else:
-            return (4 * np.pi *
-                     np.power(self.comoving_transverse_distance(z_i, z_f), 3) /\
-                     3).in_base(self.unit_system)
+            return (
+                4 * np.pi * np.power(self.comoving_transverse_distance(z_i, z_f), 3) / 3
+            ).in_base(self.unit_system)
 
     def angular_diameter_distance(self, z_i, z_f):
         r"""
-        Following Hogg (1999), the angular diameter distance is 'the ratio of 
+        Following Hogg (1999), the angular diameter distance is 'the ratio of
         an object's physical transverse size to its angular size in radians.'
 
         Parameters
@@ -247,16 +277,18 @@ class Cosmology(object):
 
         >>> from yt.utilities.cosmology import Cosmology
         >>> co = Cosmology()
-        >>> print(co.angular_diameter_distance(0., 1.).in_units("Mpc"))
-        
+        >>> print(co.angular_diameter_distance(0.0, 1.0).in_units("Mpc"))
+
         """
-        
-        return (self.comoving_transverse_distance(0, z_f) / (1 + z_f) - 
-                self.comoving_transverse_distance(0, z_i) / (1 + z_i)).in_base(self.unit_system)
+
+        return (
+            self.comoving_transverse_distance(0, z_f) / (1 + z_f)
+            - self.comoving_transverse_distance(0, z_i) / (1 + z_i)
+        ).in_base(self.unit_system)
 
     def angular_scale(self, z_i, z_f):
         r"""
-        The proper transverse distance between two points at redshift z_f 
+        The proper transverse distance between two points at redshift z_f
         observed at redshift z_i per unit of angular separation.
 
         Parameters
@@ -271,17 +303,16 @@ class Cosmology(object):
 
         >>> from yt.utilities.cosmology import Cosmology
         >>> co = Cosmology()
-        >>> print(co.angular_scale(0., 1.).in_units("kpc / arcsec"))
-        
+        >>> print(co.angular_scale(0.0, 1.0).in_units("kpc / arcsec"))
+
         """
 
-        scale = self.angular_diameter_distance(z_i, z_f) / \
-          self.quan(1, "radian")
+        scale = self.angular_diameter_distance(z_i, z_f) / self.quan(1, "radian")
         return scale.in_base(self.unit_system)
-    
+
     def luminosity_distance(self, z_i, z_f):
         r"""
-        The distance that would be inferred from the inverse-square law of 
+        The distance that would be inferred from the inverse-square law of
         light and the measured flux and luminosity of the observed object.
 
         Parameters
@@ -296,16 +327,18 @@ class Cosmology(object):
 
         >>> from yt.utilities.cosmology import Cosmology
         >>> co = Cosmology()
-        >>> print(co.luminosity_distance(0., 1.).in_units("Mpc"))
-        
+        >>> print(co.luminosity_distance(0.0, 1.0).in_units("Mpc"))
+
         """
 
-        return (self.comoving_transverse_distance(0, z_f) * (1 + z_f) - 
-                self.comoving_transverse_distance(0, z_i) * (1 + z_i)).in_base(self.unit_system)
+        return (
+            self.comoving_transverse_distance(0, z_f) * (1 + z_f)
+            - self.comoving_transverse_distance(0, z_i) * (1 + z_i)
+        ).in_base(self.unit_system)
 
     def lookback_time(self, z_i, z_f):
         r"""
-        The difference in the age of the Universe between the redshift interval 
+        The difference in the age of the Universe between the redshift interval
         z_i to z_f.
 
         Parameters
@@ -320,51 +353,16 @@ class Cosmology(object):
 
         >>> from yt.utilities.cosmology import Cosmology
         >>> co = Cosmology()
-        >>> print(co.lookback_time(0., 1.).in_units("Gyr"))
+        >>> print(co.lookback_time(0.0, 1.0).in_units("Gyr"))
 
         """
-        return (trapzint(self.age_integrand, z_i, z_f) / \
-                self.hubble_constant).in_base(self.unit_system)
-    
-    def hubble_time(self, z, z_inf=1e6):
-        r"""
-        The inverse of the Hubble parameter.
-
-        WARNING: this function is incorrect and has been deprecated!
-
-        This function currently returns the age of the Universe at a
-        given redshift instead of the inverse of the Hubble parameter.
-        To get the correct behavior, do the following:
-
-        >>> (1 / co.hubble_parameter(z)).in_units('Gyr')
-
-        Parameters
-        ----------
-        z : float
-            Redshift.
-        z_inf : float
-            The upper bound of the integral of the age integrand.
-            Default: 1e6.
-
-        Examples
-        --------
-
-        >>> from yt.utilities.cosmology import Cosmology
-        >>> co = Cosmology()
-        >>> print(co.hubble_time(0.).in_units("Gyr"))
-
-        """
-        issue_deprecation_warning(
-            'The hubble_time function is incorrect and has been deprecated! ' +
-            'Instead, do the following:\n' +
-            '>>> print (1 / co.hubble_parameter(z)).to(\'Gyr\')\n' +
-            'If you want the age of the Universe, use the t_from_z function.')
-        return (trapzint(self.age_integrand, z, z_inf) /
-                self.hubble_constant).in_base(self.unit_system)
+        return (trapzint(self.age_integrand, z_i, z_f) / self.hubble_constant).in_base(
+            self.unit_system
+        )
 
     def critical_density(self, z):
         r"""
-        The density required for closure of the Universe at a given 
+        The density required for closure of the Universe at a given
         redshift in the proper frame.
 
         Parameters
@@ -377,12 +375,13 @@ class Cosmology(object):
 
         >>> from yt.utilities.cosmology import Cosmology
         >>> co = Cosmology()
-        >>> print(co.critical_density(0.).in_units("g/cm**3"))
+        >>> print(co.critical_density(0.0).in_units("g/cm**3"))
         >>> print(co.critical_density(0).in_units("Msun/Mpc**3"))
-        
+
         """
-        return (3.0 * self.hubble_parameter(z)**2 /
-                8.0 / np.pi / G).in_base(self.unit_system)
+        return (3.0 * self.hubble_parameter(z) ** 2 / 8.0 / np.pi / G).in_base(
+            self.unit_system
+        )
 
     def hubble_parameter(self, z):
         r"""
@@ -401,20 +400,19 @@ class Cosmology(object):
         >>> print(co.hubble_parameter(1.0).in_units("km/s/Mpc"))
 
         """
-        return (self.hubble_constant.in_base(self.unit_system) *
-                self.expansion_factor(z))
+        return self.hubble_constant.in_base(self.unit_system) * self.expansion_factor(z)
 
     def age_integrand(self, z):
-        return 1. / (z + 1) / self.expansion_factor(z)
+        return 1.0 / (z + 1) / self.expansion_factor(z)
 
     def expansion_factor(self, z):
         r"""
-        The ratio between the Hubble parameter at a given redshift and 
+        The ratio between the Hubble parameter at a given redshift and
         redshift zero.
 
-        This is also the primary function integrated to calculate the 
+        This is also the primary function integrated to calculate the
         cosmological distances.
-        
+
         """
 
         # Use non-standard dark energy
@@ -426,16 +424,18 @@ class Cosmology(object):
             dark_factor = 1.0
 
         zp1 = 1 + z
-        return np.sqrt(self.omega_matter    * zp1**3 +
-                       self.omega_curvature * zp1**2 +
-                       self.omega_radiation * zp1**4 +
-                       self.omega_lambda    * dark_factor)
+        return np.sqrt(
+            self.omega_matter * zp1 ** 3
+            + self.omega_curvature * zp1 ** 2
+            + self.omega_radiation * zp1 ** 4
+            + self.omega_lambda * dark_factor
+        )
 
     def inverse_expansion_factor(self, z):
-        return 1. / self.expansion_factor(z)
+        return 1.0 / self.expansion_factor(z)
 
     def path_length_function(self, z):
-        return ((1 + z)**2) * self.inverse_expansion_factor(z)
+        return ((1 + z) ** 2) * self.inverse_expansion_factor(z)
 
     def path_length(self, z_i, z_f):
         return trapzint(self.path_length_function, z_i, z_f)
@@ -454,7 +454,7 @@ class Cosmology(object):
 
         >>> from yt.utilities.cosmology import Cosmology
         >>> co = Cosmology()
-        >>> print(co.t_from_a(1.).in_units("Gyr"))
+        >>> print(co.t_from_a(1.0).in_units("Gyr"))
 
         """
 
@@ -465,7 +465,7 @@ class Cosmology(object):
         bins_per_dex = 1000
         n_bins = int((la_f - la_i) * bins_per_dex + 1)
         la_bins = np.linspace(la_i, la_f, n_bins)
-        z_bins = 1. / np.power(10, la_bins) - 1
+        z_bins = 1.0 / np.power(10, la_bins) - 1
 
         # Integrate in redshift.
         lt = trapezoid_cumulative_integral(self.age_integrand, z_bins)
@@ -490,11 +490,11 @@ class Cosmology(object):
 
         >>> from yt.utilities.cosmology import Cosmology
         >>> co = Cosmology()
-        >>> print(co.t_from_z(0.).in_units("Gyr"))
+        >>> print(co.t_from_z(0.0).in_units("Gyr"))
 
         """
 
-        return self.t_from_a(1. / (1. + z))
+        return self.t_from_a(1.0 / (1.0 + z))
 
     def a_from_t(self, t):
         """
@@ -511,12 +511,12 @@ class Cosmology(object):
 
         >>> from yt.utilities.cosmology import Cosmology
         >>> co = Cosmology()
-        >>> print(co.a_from_t(4.e17))
+        >>> print(co.a_from_t(4.0e17))
 
         """
 
         if not isinstance(t, YTArray):
-            t = self.arr(t, 's')
+            t = self.arr(t, "s")
         lt = np.log10((t * self.hubble_constant).to(""))
 
         # Interpolate from a table of log(a) vs. log(t)
@@ -530,11 +530,10 @@ class Cosmology(object):
             good = True
             n_bins = int((la_f - la_i) * bins_per_dex + 1)
             la_bins = np.linspace(la_i, la_f, n_bins)
-            z_bins = 1. / np.power(10, la_bins) - 1
+            z_bins = 1.0 / np.power(10, la_bins) - 1
 
             # Integrate in redshift.
-            lt_bins = trapezoid_cumulative_integral(
-                self.age_integrand, z_bins)
+            lt_bins = trapezoid_cumulative_integral(self.age_integrand, z_bins)
 
             # Add a minus sign because we've switched the integration limits.
             table = InterpTable(np.log10(-lt_bins), la_bins[1:])
@@ -553,8 +552,7 @@ class Cosmology(object):
                 break
             iter += 1
             if iter > 10:
-                raise RuntimeError(
-                    "a_from_t calculation did not converge!")
+                raise RuntimeError("a_from_t calculation did not converge!")
 
         a = np.power(10, table(lt))
         return a
@@ -574,12 +572,12 @@ class Cosmology(object):
 
         >>> from yt.utilities.cosmology import Cosmology
         >>> co = Cosmology()
-        >>> print(co.z_from_t(4.e17))
+        >>> print(co.z_from_t(4.0e17))
 
         """
 
         a = self.a_from_t(t)
-        return 1. / a - 1.
+        return 1.0 / a - 1.0
 
     def get_dark_factor(self, z):
         """
@@ -588,8 +586,9 @@ class Cosmology(object):
         note that there's a typo in his eq. There should be no negative sign).
 
         At the moment, this only works using the parameterization given in Linder 2002
-        eq. 7: w(a) = w0 + wa(1 - a) = w0 + wa * z / (1+z). This gives rise to an analytic
-        expression. It is also only functional for Gadget simulations, at the moment.
+        eq. 7: w(a) = w0 + wa(1 - a) = w0 + wa * z / (1+z). This gives rise to an
+        analytic expression.
+        It is also only functional for Gadget simulations, at the moment.
 
         Parameters
         ----------
@@ -601,32 +600,36 @@ class Cosmology(object):
         scale_factor = 1.0 / (1.0 + z)
 
         # Evaluate exponential using Linder02 parameterization
-        dark_factor = np.power(scale_factor, -3.0 * (1.0 + self.w_0 + self.w_a)) * \
-                      np.exp(-3.0 * self.w_a * (1.0 - scale_factor))
+        dark_factor = np.power(
+            scale_factor, -3.0 * (1.0 + self.w_0 + self.w_a)
+        ) * np.exp(-3.0 * self.w_a * (1.0 - scale_factor))
 
         return dark_factor
 
     _arr = None
+
     @property
     def arr(self):
         if self._arr is not None:
             return self._arr
-        self._arr = functools.partial(YTArray, registry = self.unit_registry)
+        self._arr = functools.partial(YTArray, registry=self.unit_registry)
         return self._arr
-    
+
     _quan = None
+
     @property
     def quan(self):
         if self._quan is not None:
             return self._quan
-        self._quan = functools.partial(YTQuantity,
-                registry = self.unit_registry)
+        self._quan = functools.partial(YTQuantity, registry=self.unit_registry)
         return self._quan
 
+
 def trapzint(f, a, b, bins=10000):
     zbins = np.logspace(np.log10(a + 1), np.log10(b + 1), bins) - 1
     return np.trapz(f(zbins[:-1]), x=zbins[:-1], dx=np.diff(zbins))
 
+
 def trapezoid_cumulative_integral(f, x):
     """
     Perform cumulative integration using the trapezoid rule.
@@ -635,15 +638,17 @@ def trapezoid_cumulative_integral(f, x):
     fy = f(x)
     return (0.5 * (fy[:-1] + fy[1:]) * np.diff(x)).cumsum()
 
-class InterpTable(object):
+
+class InterpTable:
     """
     Generate a function to linearly interpolate from provided arrays.
     """
+
     def __init__(self, x, y):
         self.x = x
         self.y = y
 
     def __call__(self, val):
         i = np.clip(np.digitize(val, self.x) - 1, 0, self.x.size - 2)
-        slope = (self.y[i+1] - self.y[i]) / (self.x[i+1] - self.x[i])
+        slope = (self.y[i + 1] - self.y[i]) / (self.x[i + 1] - self.x[i])
         return slope * (val - self.x[i]) + self.y[i]
