@@ -1,7 +1,7 @@
-
-class Converter(object):
+class Converter:
     def __init__(self, basename, outname=None):
         self.basename = basename
         self.outname = outname
+
     def convert(self):
         pass
