@@ -1,7 +1,6 @@
-# -*- coding: utf-8 -*-
 import inspect
 from collections import Counter
-from yt.extern.six.moves import reduce
+from functools import reduce
 
 
 def find_lowest_subclasses(candidates):
@@ -12,8 +11,8 @@ def find_lowest_subclasses(candidates):
 
     Parameters
     ----------
-    candidates : iterable
-        An interable object that is a collection of classes to find the lowest
+    candidates : Iterable
+        An iterable object that is a collection of classes to find the lowest
         subclass of.
 
     Returns
@@ -27,6 +26,8 @@ def find_lowest_subclasses(candidates):
     # lowest class
     if len(candidates) == 1:
         return candidates
+    elif len(candidates) == 0:
+        return []
 
     mros = [inspect.getmro(c) for c in candidates]
 
