@@ -1,21 +1,4 @@
-"""
-Writing PNGs
-"""
-
-#-----------------------------------------------------------------------------
-# Copyright (c) 2013, yt Development Team.
-#
-# Distributed under the terms of the Modified BSD License.
-#
-# The full license is in the file COPYING.txt, distributed with this software.
-#-----------------------------------------------------------------------------
-
-from yt.extern.six import PY2
-
-if PY2:
-    from cStringIO import StringIO
-else:
-    from io import BytesIO as StringIO
+from io import BytesIO
 
 try:
     # matplotlib switched from an internal submodule _png to using pillow (PIL)
@@ -39,7 +22,7 @@ def write_png(buffer, filename, dpi=100):
 
 
 def write_png_to_string(buffer, dpi=100):
-    fileobj = StringIO()
+    fileobj = BytesIO()
     call_png_write_png(buffer, fileobj, dpi)
     png_str = fileobj.getvalue()
     fileobj.close()
