@@ -1,32 +1,19 @@
-"""
-Test for off_axis_projection and write_projection
-
-
-
-"""
-
-#-----------------------------------------------------------------------------
-# Copyright (c) 2013, yt Development Team.
-#
-# Distributed under the terms of the Modified BSD License.
-#
-# The full license is in the file COPYING.txt, distributed with this software.
-# -----------------------------------------------------------------------------
 import os
 import shutil
 import tempfile
 import unittest
 
+from yt.testing import (
+    assert_equal,
+    assert_fname,
+    expand_keywords,
+    fake_octree_ds,
+    fake_random_ds,
+)
+from yt.visualization.api import OffAxisProjectionPlot, OffAxisSlicePlot
 from yt.visualization.image_writer import write_projection
-from yt.testing import \
-    assert_equal, \
-    assert_fname, \
-    expand_keywords, \
-    fake_octree_ds, \
-    fake_random_ds
 from yt.visualization.volume_rendering.api import off_axis_projection
-from yt.visualization.api import OffAxisProjectionPlot, \
-    OffAxisSlicePlot
+
 
 class TestOffAxisProjection(unittest.TestCase):
     @classmethod
@@ -47,17 +34,17 @@ class TestOffAxisProjection(unittest.TestCase):
         test_ds = fake_random_ds(64)
         c = test_ds.domain_center
         norm = [0.5, 0.5, 0.5]
-        W = test_ds.arr([0.5,0.5,1.0], 'unitary')
+        W = test_ds.arr([0.5, 0.5, 1.0], "unitary")
         N = 256
-        field = ("gas","density")
+        field = ("gas", "density")
         oap_args = [test_ds, c, norm, W, N, field]
 
         # kwargs for off_axis_projection
         oap_kwargs = {}
-        oap_kwargs['weight'] = (None, 'cell_mass')
-        oap_kwargs['no_ghost'] = (True, False)
-        oap_kwargs['interpolated'] = (False,)
-        oap_kwargs['north_vector'] = ((1, 0, 0), (0, 0.5, 1.0))
+        oap_kwargs["weight"] = (None, "cell_mass")
+        oap_kwargs["no_ghost"] = (True, False)
+        oap_kwargs["interpolated"] = (False,)
+        oap_kwargs["north_vector"] = ((1, 0, 0), (0, 0.5, 1.0))
         oap_kwargs_list = expand_keywords(oap_kwargs)
 
         # args or write_projection
@@ -65,14 +52,15 @@ class TestOffAxisProjection(unittest.TestCase):
 
         # kwargs for write_projection
         wp_kwargs = {}
-        wp_kwargs['colorbar'] = (True, False)
-        wp_kwargs['colorbar_label'] = ('test')
-        wp_kwargs['title'] = ('test')
-        wp_kwargs['limits'] = (None, (1e3, 1e5))
-        wp_kwargs['take_log'] = (True, False)
-        wp_kwargs['figsize'] = ((8,6), [1,1])
-        wp_kwargs['dpi'] = (100, 50)
-        wp_kwargs['cmap_name'] = ('arbre', 'kelp')
+        wp_kwargs["colorbar"] = (True, False)
+        wp_kwargs["colorbar_label"] = "test"
+        wp_kwargs["title"] = "test"
+        wp_kwargs["vmin"] = (None,)
+        wp_kwargs["vmax"] = (1e3, 1e5)
+        wp_kwargs["take_log"] = (True, False)
+        wp_kwargs["figsize"] = ((8, 6), [1, 1])
+        wp_kwargs["dpi"] = (100, 50)
+        wp_kwargs["cmap_name"] = ("cmyt.arbre", "cmyt.kelp")
         wp_kwargs_list = expand_keywords(wp_kwargs)
 
         # test all off_axis_projection kwargs and write_projection kwargs
@@ -94,16 +82,21 @@ class TestOffAxisProjection(unittest.TestCase):
         write_projection(image, "test_4.eps", xlabel="x-axis", ylabel="y-axis")
         assert_fname("test_4.eps")
 
+
 def test_field_cut_off_axis_octree():
-    ds = fake_octree_ds() 
-    cut = ds.all_data().cut_region('obj["density"]>0.5') 
-    p1 = OffAxisProjectionPlot(ds, [1, 0, 0], 'density')
-    p2 = OffAxisProjectionPlot(ds, [1, 0, 0], 'density', data_source=cut)
-    assert_equal(p2.frb["density"].min() == 0.0, True) # Lots of zeros
-    assert_equal((p1.frb["density"] == p2.frb["density"]).all(), False)
-    p3 = OffAxisSlicePlot(ds, [1, 0, 0], 'density')
-    p4 = OffAxisSlicePlot(ds, [1, 0, 0], 'density', data_source=cut)
-    assert_equal((p3.frb["density"] == p4.frb["density"]).all(), False)
-    p4rho = p4.frb["density"]
-    assert_equal(p4rho.min() == 0.0, True) # Lots of zeros
+    ds = fake_octree_ds()
+    cut = ds.all_data().cut_region('obj[("gas", "density")]>0.5')
+    p1 = OffAxisProjectionPlot(ds, [1, 0, 0], ("gas", "density"))
+    p2 = OffAxisProjectionPlot(ds, [1, 0, 0], ("gas", "density"), data_source=cut)
+    assert_equal(p2.frb[("gas", "density")].min() == 0.0, True)  # Lots of zeros
+    assert_equal(
+        (p1.frb[("gas", "density")] == p2.frb[("gas", "density")]).all(), False
+    )
+    p3 = OffAxisSlicePlot(ds, [1, 0, 0], ("gas", "density"))
+    p4 = OffAxisSlicePlot(ds, [1, 0, 0], ("gas", "density"), data_source=cut)
+    assert_equal(
+        (p3.frb[("gas", "density")] == p4.frb[("gas", "density")]).all(), False
+    )
+    p4rho = p4.frb[("gas", "density")]
+    assert_equal(p4rho.min() == 0.0, True)  # Lots of zeros
     assert_equal(p4rho[p4rho > 0.0].min() >= 0.5, True)
