@@ -1,27 +1,24 @@
-"""
-Create smooth camera paths from keyframes.
-
-
-
-"""
-from __future__ import print_function
-
-#-----------------------------------------------------------------------------
-# Copyright (c) 2013, yt Development Team.
-#
-# Distributed under the terms of the Modified BSD License.
-#
-# The full license is in the file COPYING.txt, distributed with this software.
-#-----------------------------------------------------------------------------
-
 import random
+
 import numpy as np
+
 from yt.visualization.volume_rendering.create_spline import create_spline
 
-class Keyframes(object):
-    def __init__(self, x, y, z=None, north_vectors=None, up_vectors=None,
-                 times=None, niter=50000, init_temp=10.0, alpha=0.999,
-                 fixed_start=False):
+
+class Keyframes:
+    def __init__(
+        self,
+        x,
+        y,
+        z=None,
+        north_vectors=None,
+        up_vectors=None,
+        times=None,
+        niter=50000,
+        init_temp=10.0,
+        alpha=0.999,
+        fixed_start=False,
+    ):
         r"""Keyframes for camera path generation.
 
         From a set of keyframes with position and optional up and
@@ -58,19 +55,19 @@ class Keyframes(object):
         Examples
         --------
 
-        >>> import numpy as np
         >>> import matplotlib.pyplot as plt
-        >>> from yt.visualization.volume_rendering.camera_path import *
+        ... import numpy as np
+        ... from yt.visualization.volume_rendering.camera_path import *
 
-        # Make a camera path from 10 random (x,y,z) keyframes
-        >>> data = np.random.random.((10,3))
-        >>> kf = Keyframes(data[:,0], data[:,1], data[:,2])
+        >>> # Make a camera path from 10 random (x, y, z) keyframes
+        >>> data = np.random.random(10, 3)
+        >>> kf = Keyframes(data[:, 0], data[:, 1], data[:, 2])
         >>> path = kf.create_path(250, shortest_path=False)
 
-        # Plot the keyframes in the x-y plane and camera path
-        plt.plot(kf.pos[:,0], kf.pos[:,1], 'ko')
-        plt.plot(path['position'][:,0], path['position'][:,1])
-        plt.savefig('path.png')
+        >>> # Plot the keyframes in the x-y plane and camera path
+        >>> plt.plot(kf.pos[:, 0], kf.pos[:, 1], "ko")
+        >>> plt.plot(path["position"][:, 0], path["position"][:, 1])
+        >>> plt.savefig("path.png")
         """
         Nx = len(x)
         Ny = len(y)
@@ -80,17 +77,17 @@ class Keyframes(object):
         else:
             Nz = 1
             ndims = 2
-        if Nx*Ny*Nz != Nx**ndims:
+        if Nx * Ny * Nz != Nx ** ndims:
             print("Need Nx (%d) == Ny (%d) == Nz (%d)" % (Nx, Ny, Nz))
             raise RuntimeError
         self.nframes = Nx
-        self.pos = np.zeros((Nx,3))
-        self.pos[:,0] = x
-        self.pos[:,1] = y
+        self.pos = np.zeros((Nx, 3))
+        self.pos[:, 0] = x
+        self.pos[:, 1] = y
         if z is not None:
-            self.pos[:,2] = z
+            self.pos[:, 2] = z
         else:
-            self.pos[:,2] = 0.0
+            self.pos[:, 2] = 0.0
         self.north_vectors = north_vectors
         self.up_vectors = up_vectors
         if times is None:
@@ -100,8 +97,7 @@ class Keyframes(object):
         self.cartesian_matrix()
         self.setup_tsp(niter, init_temp, alpha, fixed_start)
 
-    def setup_tsp(self, niter=50000, init_temp=10.0, alpha=0.999,
-                  fixed_start=False):
+    def setup_tsp(self, niter=50000, init_temp=10.0, alpha=0.999, fixed_start=False):
         r"""Setup parameters for Travelling Salesman Problem.
 
         Parameters
@@ -135,7 +131,7 @@ class Keyframes(object):
 
     def set_times(self, times):
         self.times = times
-        
+
     def rand_seq(self):
         r"""
         Generates values in random order, equivalent to using shuffle
@@ -144,7 +140,7 @@ class Keyframes(object):
         values = range(self.nframes)
         for i in range(self.nframes):
             # pick a random index into remaining values
-            j = i + int(random.random() * (self.nframes-i))
+            j = i + int(random.random() * (self.nframes - i))
             # swap the values
             values[j], values[i] = values[i], values[j]
             # return the swapped value
@@ -156,25 +152,26 @@ class Keyframes(object):
         """
         for i in self.rand_seq():
             for j in self.rand_seq():
-                yield (i,j)
-    
+                yield (i, j)
+
     def reversed_sections(self, tour):
         r"""
         Generator to return all possible variations where a section
         between two cities are swapped.
         """
-        for i,j in self.all_pairs():
-            if i == j: continue
+        for i, j in self.all_pairs():
+            if i == j:
+                continue
             copy = tour[:]
             if i < j:
-                copy[i:j+1] = reversed(tour[i:j+1])
+                copy[i : j + 1] = reversed(tour[i : j + 1])
             else:
-                copy[i+1:] = reversed(tour[:j])
-                copy[:j] = reversed(tour[i+1:])
+                copy[i + 1 :] = reversed(tour[:j])
+                copy[:j] = reversed(tour[i + 1 :])
             if self.fixed_start:
                 ind = copy.index(0)
                 copy[0], copy[ind] = copy[ind], copy[0]
-            if copy != tour: # no point return the same tour
+            if copy != tour:  # no point return the same tour
                 yield copy
 
     def cartesian_matrix(self):
@@ -184,15 +181,15 @@ class Keyframes(object):
         """
         self.dist_matrix = np.zeros((self.nframes, self.nframes))
         xmat = np.zeros((self.nframes, self.nframes))
-        xmat[:,:] = self.pos[:,0]
+        xmat[:, :] = self.pos[:, 0]
         dx = xmat - xmat.T
         ymat = np.zeros((self.nframes, self.nframes))
-        ymat[:,:] = self.pos[:,1]
+        ymat[:, :] = self.pos[:, 1]
         dy = ymat - ymat.T
         zmat = np.zeros((self.nframes, self.nframes))
-        zmat[:,:] = self.pos[:,2]
+        zmat[:, :] = self.pos[:, 2]
         dz = zmat - zmat.T
-        self.dist_matrix = np.sqrt(dx*dx + dy*dy + dz*dz)
+        self.dist_matrix = np.sqrt(dx * dx + dy * dy + dz * dz)
 
     def tour_length(self, tour):
         r"""
@@ -202,7 +199,7 @@ class Keyframes(object):
         total = 0
         num_cities = len(tour)
         for i in range(num_cities):
-            j = (i+1) % num_cities
+            j = (i + 1) % num_cities
             city_i = tour[i]
             city_j = tour[j]
             total += self.dist_matrix[city_i, city_j]
@@ -218,14 +215,11 @@ class Keyframes(object):
         if next > prev:
             return 1.0
         else:
-            return np.exp( -abs(next-prev) / temperature )
+            return np.exp(-abs(next - prev) / temperature)
 
     def get_shortest_path(self):
-        r"""Determine shortest path between all keyframes.
-
-        Parameters
-        ----------
-        None.
+        """
+        Determine shortest path between all keyframes.
         """
         # this obviously doesn't work. When someone fixes it, remove the NOQA
         self.setup_tsp(niter, init_temp, alpha, fixed_start)  # NOQA
@@ -250,14 +244,14 @@ class Keyframes(object):
                     current = next
                     self.current_score = next_score
                     if self.current_score > self.best_score:
-                        #print num_eval, self.current_score, self.best_score, current
+                        # print(num_eval, self.current_score, self.best_score, current)
                         self.best_score = self.current_score
                         self.best = current
                     break
 
             if done:
                 break
-        self.pos = self.pos[self.tour,:]
+        self.pos = self.pos[self.tour, :]
         if self.north_vectors is not None:
             self.north_vectors = self.north_vectors[self.tour]
         if self.up_vectors is not None:
@@ -286,26 +280,29 @@ class Keyframes(object):
             path.  Also saved to self.path.
         """
         self.npoints = npoints
-        self.path = {"time": np.zeros(npoints),
-                     "position": np.zeros((npoints, 3)),
-                     "north_vectors": np.zeros((npoints,3)),
-                     "up_vectors": np.zeros((npoints,3))}
+        self.path = {
+            "time": np.zeros(npoints),
+            "position": np.zeros((npoints, 3)),
+            "north_vectors": np.zeros((npoints, 3)),
+            "up_vectors": np.zeros((npoints, 3)),
+        }
         if shortest_path:
             self.get_shortest_path()
         if path_time is None:
             path_time = np.linspace(0, self.nframes, npoints)
         self.path["time"] = path_time
         for dim in range(3):
-            self.path["position"][:,dim] = create_spline(self.times, self.pos[:,dim],
-                                                         path_time, tension=tension)
+            self.path["position"][:, dim] = create_spline(
+                self.times, self.pos[:, dim], path_time, tension=tension
+            )
             if self.north_vectors is not None:
-                self.path["north_vectors"][:,dim] = \
-                    create_spline(self.times, self.north_vectors[:,dim],
-                                  path_time, tension=tension)
+                self.path["north_vectors"][:, dim] = create_spline(
+                    self.times, self.north_vectors[:, dim], path_time, tension=tension
+                )
             if self.up_vectors is not None:
-                self.path["up_vectors"][:,dim] = \
-                    create_spline(self.times, self.up_vectors[:,dim],
-                                  path_time, tension=tension)
+                self.path["up_vectors"][:, dim] = create_spline(
+                    self.times, self.up_vectors[:, dim], path_time, tension=tension
+                )
         return self.path
 
     def write_path(self, filename="path.dat"):
@@ -317,16 +314,23 @@ class Keyframes(object):
             Filename containing the camera path.  Default: path.dat
         """
         fp = open(filename, "w")
-        fp.write("#%11s %12s %12s %12s %12s %12s %12s %12s %12s\n" %
-                 ("x", "y", "z", "north_x", "north_y", "north_z",
-                  "up_x", "up_y", "up_z"))
+        fp.write(
+            "#%11s %12s %12s %12s %12s %12s %12s %12s %12s\n"
+            % ("x", "y", "z", "north_x", "north_y", "north_z", "up_x", "up_y", "up_z")
+        )
         for i in range(self.npoints):
-            fp.write("%.12f %.12f %.12f %.12f %.12f %.12f %.12f %.12f %.12f\n" %
-                     (self.path["position"][i,0], self.path["position"][i,1],
-                      self.path["position"][i,2], 
-                      self.path["north_vectors"][i,0], self.path["north_vectors"][i,1],
-                      self.path["north_vectors"][i,2], 
-                      self.path["up_vectors"][i,0], self.path["up_vectors"][i,1],
-                      self.path["up_vectors"][i,2]))
+            fp.write(
+                "%.12f %.12f %.12f %.12f %.12f %.12f %.12f %.12f %.12f\n"
+                % (
+                    self.path["position"][i, 0],
+                    self.path["position"][i, 1],
+                    self.path["position"][i, 2],
+                    self.path["north_vectors"][i, 0],
+                    self.path["north_vectors"][i, 1],
+                    self.path["north_vectors"][i, 2],
+                    self.path["up_vectors"][i, 0],
+                    self.path["up_vectors"][i, 1],
+                    self.path["up_vectors"][i, 2],
+                )
+            )
         fp.close()
-
